@@ -2,14 +2,14 @@
 
 # For the release-staging branch his script bumps the Tensile version and hash
 
-OLD_TENSILE_VERSION="TENSILE_VERSION 4.37.0"
-NEW_TENSILE_VERSION="TENSILE_VERSION 4.38.0"
+OLD_TENSILE_VERSION="TENSILE_VERSION 4.39.0"
+NEW_TENSILE_VERSION="TENSILE_VERSION 4.40.0"
 
-OLD_TENSILE_HASH="aba52fa129099cd7c32b322f5daa1a586ad0792b"
-NEW_TENSILE_HASH="bbc96e67e96f178b1d9400473e020a2a5c6bafb3"
+OLD_TENSILE_HASH="3a4153ac72b11c5258e7a5687bbb11d9bc739680"
+NEW_TENSILE_HASH="d23b84ae6499b922831c11e75b1daa58d520fe01"
 
-OLD_SO_VERSION="rocblas_SOVERSION 3.1.0"
-NEW_SO_VERSION="rocblas_SOVERSION 3.1.0"
+OLD_SO_VERSION="rocblas_SOVERSION 4.1"
+NEW_SO_VERSION="rocblas_SOVERSION 4.1"
 
 sed -i "s/${OLD_TENSILE_VERSION}/${NEW_TENSILE_VERSION}/g" CMakeLists.txt
 
