@@ -38,6 +38,7 @@
 #include <stdexcept>
 #include <string>
 #include <type_traits>
+
 // aux
 #include "testing_set_get_matrix.hpp"
 #include "testing_set_get_matrix_async.hpp"
@@ -165,7 +166,7 @@
 #include "testing_trsv.hpp"
 #include "testing_trsv_batched.hpp"
 #include "testing_trsv_strided_batched.hpp"
-// blas3 with no tensile
+// blas3 with no tensile, some may use source gemm
 #include "testing_dgmm.hpp"
 #include "testing_dgmm_batched.hpp"
 #include "testing_dgmm_strided_batched.hpp"
@@ -173,6 +174,9 @@
 #include "testing_geam_batched.hpp"
 #include "testing_geam_ex.hpp"
 #include "testing_geam_strided_batched.hpp"
+#include "testing_gemmt.hpp"
+#include "testing_gemmt_batched.hpp"
+#include "testing_gemmt_strided_batched.hpp"
 #include "testing_her2k.hpp"
 #include "testing_her2k_batched.hpp"
 #include "testing_her2k_strided_batched.hpp"
@@ -188,15 +192,34 @@
 #include "testing_syrk.hpp"
 #include "testing_syrk_batched.hpp"
 #include "testing_syrk_strided_batched.hpp"
-#include "testing_trmm_outofplace.hpp"
-#include "testing_trmm_outofplace_batched.hpp"
-#include "testing_trmm_outofplace_strided_batched.hpp"
-//
+#include "testing_trmm.hpp"
+#include "testing_trmm_batched.hpp"
+#include "testing_trmm_strided_batched.hpp"
 #include "type_dispatch.hpp"
 #include "utility.hpp"
-#include <algorithm>
 #undef I
 
+#if BUILD_WITH_TENSILE
+#include "testing_gemm.hpp"
+#include "testing_gemm_batched.hpp"
+#include "testing_gemm_batched_ex.hpp"
+#include "testing_gemm_batched_ex3.hpp"
+#include "testing_gemm_ex.hpp"
+#include "testing_gemm_ex3.hpp"
+#include "testing_gemm_strided_batched.hpp"
+#include "testing_gemm_strided_batched_ex.hpp"
+#include "testing_gemm_strided_batched_ex3.hpp"
+#include "testing_trsm.hpp"
+#include "testing_trsm_batched.hpp"
+#include "testing_trsm_batched_ex.hpp"
+#include "testing_trsm_ex.hpp"
+#include "testing_trsm_strided_batched.hpp"
+#include "testing_trsm_strided_batched_ex.hpp"
+#include "testing_trtri.hpp"
+#include "testing_trtri_batched.hpp"
+#include "testing_trtri_strided_batched.hpp"
+#endif
+
 using namespace roc; // For emulated program_options
 using namespace std::literals; // For std::string literals of form "str"s
 
@@ -223,28 +246,6 @@ void run_function(const func_map& map, const Arguments& arg, const std::string&
 
 #if BUILD_WITH_TENSILE
 
-#include "testing_gemm.hpp"
-#include "testing_gemm_batched.hpp"
-#include "testing_gemm_batched_ex.hpp"
-#include "testing_gemm_ex.hpp"
-#include "testing_gemm_ex3.hpp"
-#include "testing_gemm_strided_batched.hpp"
-#include "testing_gemm_strided_batched_ex.hpp"
-#ifndef ROCBLAS_V3
-#include "testing_trmm.hpp"
-#include "testing_trmm_batched.hpp"
-#include "testing_trmm_strided_batched.hpp"
-#endif //  ROCBLAS_V3
-#include "testing_trsm.hpp"
-#include "testing_trsm_batched.hpp"
-#include "testing_trsm_batched_ex.hpp"
-#include "testing_trsm_ex.hpp"
-#include "testing_trsm_strided_batched.hpp"
-#include "testing_trsm_strided_batched_ex.hpp"
-#include "testing_trtri.hpp"
-#include "testing_trtri_batched.hpp"
-#include "testing_trtri_strided_batched.hpp"
-
 // Template to dispatch testing_gemm_ex for performance tests
 // When Ti == void or Ti == To == Tc == bfloat16, the test is marked invalid
 template <typename Ti, typename To = Ti, typename Tc = To, typename = void>
@@ -288,16 +289,16 @@ struct perf_gemm_ex3<
     Tc,
     std::enable_if_t<(!std::is_same<TiA, void>{} && !std::is_same<TiB, void>{})
                      && ((std::is_same<TiA, rocblas_f8>{} || std::is_same<TiA, rocblas_bf8>{}
-                          || std::is_same<TiA, rocblas_half>{} || std::is_same<TiA, float>{}
-                          || std::is_same<TiA, rocblas_bfloat16>{}))
+                          || std::is_same<TiA, rocblas_half>{} || std::is_same<TiA, float>{}))
                      && (std::is_same<TiB, rocblas_f8>{} || std::is_same<TiB, rocblas_bf8>{}
-                         || std::is_same<TiB, rocblas_half>{} || std::is_same<TiB, float>{}
-                         || std::is_same<TiB, rocblas_bfloat16>{})>> : rocblas_test_valid
+                         || std::is_same<TiB, rocblas_half>{} || std::is_same<TiB, float>{})>>
+    : rocblas_test_valid
 {
     void operator()(const Arguments& arg)
     {
         static const func_map map = {
             {"gemm_ex3", testing_gemm_ex3<TiA, TiB, To, Tc>},
+            {"gemm_batched_ex3", testing_gemm_batched_ex3<TiA, TiB, To, Tc>},
         };
         run_function(map, arg);
     }
@@ -330,6 +331,35 @@ struct perf_gemm_strided_batched_ex<
     }
 };
 
+// Template to dispatch testing_gemm_ex3 for performance tests
+// When Ti == void or Ti == To == Tc == bfloat16, the test is marked invalid
+template <typename TiA, typename TiB = TiA, typename To = TiA, typename Tc = To, typename = void>
+struct perf_gemm_strided_batched_ex3 : rocblas_test_invalid
+{
+};
+
+template <typename TiA, typename TiB, typename To, typename Tc>
+struct perf_gemm_strided_batched_ex3<
+    TiA,
+    TiB,
+    To,
+    Tc,
+    std::enable_if_t<(!std::is_same<TiA, void>{} && !std::is_same<TiB, void>{})
+                     && ((std::is_same<TiA, rocblas_f8>{} || std::is_same<TiA, rocblas_bf8>{}
+                          || std::is_same<TiA, rocblas_half>{} || std::is_same<TiA, float>{}))
+                     && (std::is_same<TiB, rocblas_f8>{} || std::is_same<TiB, rocblas_bf8>{}
+                         || std::is_same<TiB, rocblas_half>{} || std::is_same<TiB, float>{})>>
+    : rocblas_test_valid
+{
+    void operator()(const Arguments& arg)
+    {
+        static const func_map map = {
+            {"gemm_strided_batched_ex3", testing_gemm_strided_batched_ex3<TiA, TiB, To, Tc>},
+        };
+        run_function(map, arg);
+    }
+};
+
 #endif // BUILD_WITH_TENSILE
 
 template <typename T, typename U = T, typename = void>
@@ -388,8 +418,6 @@ struct perf_blas<T, U, std::enable_if_t<std::is_same_v<T, float> || std::is_same
                 {"geam_strided_batched", testing_geam_strided_batched<T>},
                 {"geam_ex", testing_geam_ex<T>},
                 {"gemv", testing_gemv<T>},
-                {"gemv_batched", testing_gemv_batched<T>},
-                {"gemv_strided_batched", testing_gemv_strided_batched<T>},
                 {"ger", testing_ger<T, false>},
                 {"ger_batched", testing_ger_batched<T, false>},
                 {"ger_strided_batched", testing_ger_strided_batched<T, false>},
@@ -433,9 +461,15 @@ struct perf_blas<T, U, std::enable_if_t<std::is_same_v<T, float> || std::is_same
                 {"dgmm", testing_dgmm<T>},
                 {"dgmm_batched", testing_dgmm_batched<T>},
                 {"dgmm_strided_batched", testing_dgmm_strided_batched<T>},
+                {"gemmt", testing_gemmt<T>},
+                {"gemmt_batched", testing_gemmt_batched<T>},
+                {"gemmt_strided_batched", testing_gemmt_strided_batched<T>},
                 {"symm", testing_symm_hemm<T, false>},
                 {"symm_batched", testing_symm_hemm_batched<T, false>},
                 {"symm_strided_batched", testing_symm_hemm_strided_batched<T, false>},
+                {"trmm", testing_trmm<T>},
+                {"trmm_batched", testing_trmm_batched<T>},
+                {"trmm_strided_batched", testing_trmm_strided_batched<T>},
                 {"syrk", testing_syrk<T>},
                 {"syrk_batched", testing_syrk_batched<T>},
                 {"syrk_strided_batched", testing_syrk_strided_batched<T>},
@@ -445,18 +479,10 @@ struct perf_blas<T, U, std::enable_if_t<std::is_same_v<T, float> || std::is_same
                 {"trsv", testing_trsv<T>},
                 {"trsv_batched", testing_trsv_batched<T>},
                 {"trsv_strided_batched", testing_trsv_strided_batched<T>},
-                {"trmm_outofplace", testing_trmm_outofplace<T>},
-                {"trmm_outofplace_batched", testing_trmm_outofplace_batched<T>},
-                {"trmm_outofplace_strided_batched", testing_trmm_outofplace_strided_batched<T>},
 #if BUILD_WITH_TENSILE
                 {"syrkx", testing_syr2k<T, false>},
                 {"syrkx_batched", testing_syr2k_batched<T, false>},
                 {"syrkx_strided_batched", testing_syr2k_strided_batched<T, false>},
-#ifndef ROCBLAS_V3
-                {"trmm", testing_trmm<T>},
-                {"trmm_batched", testing_trmm_batched<T>},
-                {"trmm_strided_batched", testing_trmm_strided_batched<T>},
-#endif //  ROCBLAS_V3
                 {"trtri", testing_trtri<T>},
                 {"trtri_batched", testing_trtri_batched<T>},
                 {"trtri_strided_batched", testing_trtri_strided_batched<T>},
@@ -512,6 +538,39 @@ struct perf_blas<T, U, std::enable_if_t<std::is_same_v<T, rocblas_half>>> : rocb
     }
 };
 
+// rocblas-bench dispatch for gemv_batched and gemv_strided_batched tests
+template <typename Ti, typename Tex = Ti, typename To = Tex, typename = void>
+struct perf_gemv_batched_and_strided_batched : rocblas_test_invalid
+{
+};
+
+template <typename Ti, typename Tex, typename To>
+struct perf_gemv_batched_and_strided_batched<
+    Ti,
+    Tex,
+    To,
+    std::enable_if_t<
+        (std::is_same<Ti, float>{} && std::is_same<To, Ti>{} && std::is_same<Tex, To>{})
+        || (std::is_same<Ti, double>{} && std::is_same<To, Ti>{} && std::is_same<Tex, To>{})
+        || (std::is_same<Ti, rocblas_float_complex>{} && std::is_same<To, Ti>{}
+            && std::is_same<Tex, To>{})
+        || (std::is_same<Ti, rocblas_double_complex>{} && std::is_same<To, Ti>{}
+            && std::is_same<Tex, To>{})
+        || (std::is_same<Ti, rocblas_half>{} && std::is_same<Tex, float>{}
+            && (std::is_same<To, Ti>{} || std::is_same<To, float>{}))
+        || (std::is_same<Ti, rocblas_bfloat16>{} && std::is_same<Tex, float>{}
+            && (std::is_same<To, Ti>{} || std::is_same<To, float>{}))>> : rocblas_test_valid
+{
+    void operator()(const Arguments& arg)
+    {
+        static const func_map map = {
+            {"gemv_batched", testing_gemv_batched<Ti, Tex, To>},
+            {"gemv_strided_batched", testing_gemv_strided_batched<Ti, Tex, To>},
+        };
+        run_function(map, arg);
+    }
+};
+
 template <typename T, typename U>
 struct perf_blas<
     T,
@@ -560,8 +619,6 @@ struct perf_blas<
                 {"gbmv_batched", testing_gbmv_batched<T>},
                 {"gbmv_strided_batched", testing_gbmv_strided_batched<T>},
                 {"gemv", testing_gemv<T>},
-                {"gemv_batched", testing_gemv_batched<T>},
-                {"gemv_strided_batched", testing_gemv_strided_batched<T>},
                 {"geru", testing_ger<T, false>},
                 {"geru_batched", testing_ger_batched<T, false>},
                 {"geru_strided_batched", testing_ger_strided_batched<T, false>},
@@ -623,6 +680,9 @@ struct perf_blas<
                 {"dgmm", testing_dgmm<T>},
                 {"dgmm_batched", testing_dgmm_batched<T>},
                 {"dgmm_strided_batched", testing_dgmm_strided_batched<T>},
+                {"gemmt", testing_gemmt<T>},
+                {"gemmt_batched", testing_gemmt_batched<T>},
+                {"gemmt_strided_batched", testing_gemmt_strided_batched<T>},
                 {"geam", testing_geam<T>},
                 {"geam_batched", testing_geam_batched<T>},
                 {"geam_strided_batched", testing_geam_strided_batched<T>},
@@ -632,9 +692,15 @@ struct perf_blas<
                 {"syr2k", testing_syr2k<T>},
                 {"syr2k_batched", testing_syr2k_batched<T>},
                 {"syr2k_strided_batched", testing_syr2k_strided_batched<T>},
+                {"syrkx", testing_syr2k<T, false>},
+                {"syrkx_batched", testing_syr2k_batched<T, false>},
+                {"syrkx_strided_batched", testing_syr2k_strided_batched<T, false>},
                 {"symm", testing_symm_hemm<T, false>},
                 {"symm_batched", testing_symm_hemm_batched<T, false>},
                 {"symm_strided_batched", testing_symm_hemm_strided_batched<T, false>},
+                {"trmm", testing_trmm<T>},
+                {"trmm_batched", testing_trmm_batched<T>},
+                {"trmm_strided_batched", testing_trmm_strided_batched<T>},
                 {"hemm", testing_symm_hemm<T, true>},
                 {"hemm_batched", testing_symm_hemm_batched<T, true>},
                 {"hemm_strided_batched", testing_symm_hemm_strided_batched<T, true>},
@@ -647,16 +713,7 @@ struct perf_blas<
                 {"herkx", testing_her2k<T, false>},
                 {"herkx_batched", testing_her2k_batched<T, false>},
                 {"herkx_strided_batched", testing_her2k_strided_batched<T, false>},
-                {"trmm_outofplace", testing_trmm_outofplace<T>},
-                {"trmm_outofplace_batched", testing_trmm_outofplace_batched<T>},
-                {"trmm_outofplace_strided_batched", testing_trmm_outofplace_strided_batched<T>},
 #if BUILD_WITH_TENSILE
-                {"syrkx", testing_syr2k<T, false>},
-                {"syrkx_batched", testing_syr2k_batched<T, false>},
-                {"syrkx_strided_batched", testing_syr2k_strided_batched<T, false>},
-                {"trtri", testing_trtri<T>},
-                {"trtri_batched", testing_trtri_batched<T>},
-                {"trtri_strided_batched", testing_trtri_strided_batched<T>},
                 {"gemm", testing_gemm<T>},
                 {"gemm_batched", testing_gemm_batched<T>},
                 {"gemm_strided_batched", testing_gemm_strided_batched<T>},
@@ -666,11 +723,9 @@ struct perf_blas<
                 {"trsm_batched_ex", testing_trsm_batched_ex<T>},
                 {"trsm_strided_batched", testing_trsm_strided_batched<T>},
                 {"trsm_strided_batched_ex", testing_trsm_strided_batched_ex<T>},
-#ifndef ROCBLAS_V3
-                {"trmm", testing_trmm<T>},
-                {"trmm_batched", testing_trmm_batched<T>},
-                {"trmm_strided_batched", testing_trmm_strided_batched<T>},
-#endif //  ROCBLAS_V3
+                {"trtri", testing_trtri<T>},
+                {"trtri_batched", testing_trtri_batched<T>},
+                {"trtri_strided_batched", testing_trtri_strided_batched<T>},
 #endif
               };
         run_function(map, arg);
@@ -1163,7 +1218,7 @@ int run_bench_test(bool               init,
         }
         rocblas_gemm_dispatch<perf_gemm_ex>(arg);
     }
-    else if(!strcmp(function, "gemm_ex3"))
+    else if(!strcmp(function, "gemm_ex3") || !strcmp(function, "gemm_batched_ex3"))
     {
         // adjust dimension for GEMM routines
         rocblas_int min_lda = arg.transA == 'N' ? arg.M : arg.K;
@@ -1243,6 +1298,50 @@ int run_bench_test(bool               init,
 
         rocblas_gemm_dispatch<perf_gemm_strided_batched_ex>(arg);
     }
+    else if(!strcmp(function, "gemm_strided_batched_ex3"))
+    {
+        // adjust dimension for GEMM routines
+        rocblas_int min_lda = arg.transA == 'N' ? arg.M : arg.K;
+        rocblas_int min_ldb = arg.transB == 'N' ? arg.K : arg.N;
+        rocblas_int min_ldc = arg.M;
+        rocblas_int min_ldd = arg.M;
+        if(arg.lda < min_lda)
+        {
+            rocblas_cout << "rocblas-bench INFO: lda < min_lda, set lda = " << min_lda << std::endl;
+            arg.lda = min_lda;
+        }
+        if(arg.ldb < min_ldb)
+        {
+            rocblas_cout << "rocblas-bench INFO: ldb < min_ldb, set ldb = " << min_ldb << std::endl;
+            arg.ldb = min_ldb;
+        }
+        if(arg.ldc < min_ldc)
+        {
+            rocblas_cout << "rocblas-bench INFO: ldc < min_ldc, set ldc = " << min_ldc << std::endl;
+            arg.ldc = min_ldc;
+        }
+        if(arg.ldd < min_ldd)
+        {
+            rocblas_cout << "rocblas-bench INFO: ldd < min_ldd, set ldd = " << min_ldc << std::endl;
+            arg.ldd = min_ldd;
+        }
+        rocblas_int min_stride_c = arg.ldc * arg.N;
+        rocblas_int min_stride_d = arg.ldd * arg.N;
+        if(!any_stride && arg.stride_c < min_stride_c)
+        {
+            rocblas_cout << "rocblas-bench INFO: stride_c < min_stride_c, set stride_c = "
+                         << min_stride_c << std::endl;
+            arg.stride_c = min_stride_c;
+        }
+        if(!any_stride && arg.stride_d < min_stride_d)
+        {
+            rocblas_cout << "rocblas-bench INFO: stride_d < min_stride_d, set stride_d = "
+                         << min_stride_d << std::endl;
+            arg.stride_d = min_stride_d;
+        }
+
+        rocblas_gemm_dispatch<perf_gemm_strided_batched_ex3>(arg);
+    }
     else
 #endif
     {
@@ -1272,6 +1371,9 @@ int run_bench_test(bool               init,
         else if(!strcmp(function, "scal_ex") || !strcmp(function, "scal_batched_ex")
                 || !strcmp(function, "scal_strided_batched_ex"))
             rocblas_blas1_ex_dispatch<perf_blas_scal_ex>(arg);
+        else if(!strcmp(function, "gemv_batched") || !strcmp(function, "gemv_strided_batched"))
+            rocblas_gemv_batched_and_strided_batched_dispatch<
+                perf_gemv_batched_and_strided_batched>(arg);
         else
             rocblas_simple_dispatch<perf_blas>(arg);
     }
@@ -1380,16 +1482,19 @@ try
     std::string arithmetic_check;
     std::string filter;
     std::string name_filter;
-    int32_t     device_id;
-    int32_t     parallel_devices;
+    int32_t     device_id           = 0;
+    int32_t     parallel_devices    = 0;
     int32_t     flags               = 0;
     int32_t     geam_ex_op          = 0;
+    int32_t     api                 = 0;
     bool        datafile            = rocblas_parse_data(argc, argv);
+    bool        atomics_allowed     = true;
     bool        atomics_not_allowed = false;
     bool        log_function_name   = false;
     bool        log_datatype        = false;
     bool        any_stride          = false;
     uint32_t    math_mode           = 0;
+    uint64_t    flush_malloc_size   = 0;
     bool        fortran             = false;
 
     arg.init(); // set all defaults
@@ -1582,17 +1687,21 @@ try
          value<int32_t>(&arg.solution_index)->default_value(0),
          "extended precision gemm solution index")
 
+        ("flags",
+         value<int32_t>(&flags)->default_value(rocblas_gemm_flags_none),
+         "gemm_ex flags, see rocblas_gemm_flags enum in documentation")
+
         ("geam_ex_op",
          value<int32_t>(&geam_ex_op)->default_value(rocblas_geam_ex_operation_min_plus),
          "geam_ex_operation, 0: min_plus operation, 1: plus_min operation")
 
-        ("flags",
-         value<int32_t>(&flags)->default_value(rocblas_gemm_flags_none),
-         "gemm_ex flags, 1: Use packed-i8, 0: (default) uses unpacked-i8, available on matrix-inst-supported device")
+        ("atomics_allowed",
+         bool_switch(&atomics_allowed)->default_value(true),
+         "Atomic operations with non-determinism in results are allowed (default true)")
 
         ("atomics_not_allowed",
          bool_switch(&atomics_not_allowed)->default_value(false),
-         "Atomic operations with non-determinism in results are not allowed")
+         "Atomic operations with non-determinism in results are not allowed (default false)")
 
         ("device",
          value<int32_t>(&device_id)->default_value(0),
@@ -1602,14 +1711,18 @@ try
          value<int32_t>(&parallel_devices)->default_value(0),
          "Set number of devices used for parallel runs (device 0 to parallel_devices-1)")
 
-        ("c_noalias_d",
-         bool_switch(&arg.c_noalias_d)->default_value(false),
-         "C and D are stored in separate memory")
+        ("outofplace",
+         bool_switch(&arg.outofplace)->default_value(false),
+         "for gemm_ex C and D are stored in separate memory, for trmm B and C are stored in separate memory")
 
         ("fortran",
          bool_switch(&fortran)->default_value(false),
          "Run using Fortran interface")
 
+        ("api",
+         value<int32_t>(&api)->default_value(0),
+         "Use API, supercedes fortran flag (0==C, 1==C_64, ...)")
+
         ("workspace",
          value<size_t>(&arg.user_allocated_workspace)->default_value(0),
          "Set fixed workspace memory size instead of using rocblas managed memory")
@@ -1630,6 +1743,10 @@ try
          value<uint32_t>(&arg.math_mode)->default_value(rocblas_default_math),
          "extended precision gemm math mode")
 
+        ("flush_malloc_size",
+         value<uint64_t>(&arg.flush_malloc_size)->default_value(0),
+         "Set to 2x cache size for cache flushing in timing code")
+
         ("name_filter",
          value<std::string>(&name_filter),
          "Simple strstr filter on test name only without wildcards, only used with --yaml or --data")
@@ -1672,7 +1789,10 @@ try
     // transfer local variable state
 
     arg.atomics_mode = atomics_not_allowed ? rocblas_atomics_not_allowed : rocblas_atomics_allowed;
-    if(fortran)
+
+    if(api)
+        arg.api = rocblas_client_api(api);
+    else if(fortran)
         arg.api = FORTRAN;
 
     static const char* fp16AltImplEnvStr = std::getenv("ROCBLAS_INTERNAL_FP16_ALT_IMPL");
