@@ -33,6 +33,19 @@
  * ===========================================================================
  */
 
+template <>
+void cblas_nrm2<float>(int64_t n, const float* x, int64_t incx, float* result)
+{
+    if(n <= 0 || incx <= 0)
+        return;
+
+    host_vector<double> x_double(n * incx);
+    for(size_t i = 0; i < n; i++)
+        x_double[i * incx] = x[i * incx];
+
+    *result = float(cblas_dnrm2(n, x_double, incx));
+}
+
 template <>
 void cblas_nrm2<rocblas_half>(int64_t n, const rocblas_half* x, int64_t incx, rocblas_half* result)
 {
@@ -80,6 +93,31 @@ void cblas_axpy<rocblas_half>(
     // cblas_saxpy(n, alpha, x_float, incx, y_float, incy);
 }
 
+template <>
+void cblas_asum<float>(int64_t n, const float* x, int64_t incx, float* result)
+{
+    if(n <= 0 || incx <= 0)
+        return;
+
+    float sum = 0;
+
+    // using partial sums to reduce rounding errors for 64-bit n
+    int64_t block_size = 1024 * 512;
+    int64_t blocks     = (n - 1) / block_size + 1;
+    for(int64_t b = 0; b < blocks; b++)
+    {
+        float partial_sum = 0;
+        for(int64_t i = 0; i < block_size; i++)
+        {
+            int64_t idx = i + b * block_size;
+            if(idx < n)
+                partial_sum += std::abs(x[idx * incx]);
+        }
+        sum += partial_sum;
+    }
+    *result = sum;
+}
+
 /**
   *
   * cblas_scal(int64_t n, T alpha, U x, int64_t incx)
@@ -166,7 +204,7 @@ void cblas_dot<rocblas_half>(int64_t             n,
     int64_t iy = incy >= 0 ? 0 : (1 - n) * incy;
 
     float r = 0.0f;
-    for(size_t i = 0; i < n; i++)
+    for(int64_t i = 0; i < n; i++)
     {
         r += float(x[ix]) * float(y[iy]);
         ix += incx;
@@ -188,7 +226,7 @@ void cblas_dot<rocblas_bfloat16>(int64_t                 n,
     int64_t iy = incy >= 0 ? 0 : (1 - n) * incy;
 
     float r = 0.0f;
-    for(size_t i = 0; i < n; i++)
+    for(int64_t i = 0; i < n; i++)
     {
         r += float(x[ix]) * float(y[iy]);
         ix += incx;
@@ -320,6 +358,146 @@ void cblas_rot<rocblas_bfloat16>(int64_t                 n,
  * ===========================================================================
  */
 
+/**
+  *
+  * cblas_gemv(rocblas_operation transA, int64_t m, int64_t n, float  alpha, Ti* A, int64_t lda, Ti* x, int64_t incx, float beta, To* y, int64_t incy)
+  *
+  * Info about cblas_gemv function:
+  *
+  *    The reason why we call cblas_gemv instead of directly calling BLIS gemv is because of different input/output parameter type
+  *
+  *  Currently supported datatypes are as follows:
+  *
+  *  |---------------------------------------|
+  *  | input_type(Ti)    | ouptut_type (To)  |
+  *  |-------------------|-------------------|
+  *  |        bf16_r     |     f32_r         |
+  *  |        bf16_r     |     bf16_r        |
+  *  |        f16_r      |     f16_r         |
+  *  |        f16_r      |     f32_r         |
+  *  |---------------------------------------|
+  *
+**/
+
+template <typename Ti, typename To, typename Ta>
+void cblas_gemv(rocblas_operation transA,
+                int64_t           m,
+                int64_t           n,
+                Ta                alpha,
+                Ti*               A,
+                int64_t           lda,
+                Ti*               x,
+                int64_t           incx,
+                Ta                beta,
+                To*               y,
+                int64_t           incy)
+{
+    if constexpr(std::is_same_v<Ti, rocblas_half> || std::is_same_v<Ti, rocblas_bfloat16>)
+    {
+        // Ti == fp16/bf16
+        // To == Ti/float
+        // Ta == float
+        int64_t dim_x    = transA == rocblas_operation_none ? n : m;
+        int64_t dim_y    = transA == rocblas_operation_none ? m : n;
+        size_t  abs_incx = incx >= 0 ? incx : -incx;
+        size_t  abs_incy = incy >= 0 ? incy : -incy;
+
+        host_vector<float> A_float(size_t(lda) * n), X_float(dim_x * abs_incx);
+
+        for(size_t i = 0; i < size_t(lda) * n; i++)
+            A_float[i] = static_cast<float>(A[i]);
+
+        for(int64_t i = 0; i < dim_x; i++)
+            X_float[i * abs_incx] = static_cast<float>(x[i * abs_incx]);
+
+        if constexpr(std::is_same_v<To, rocblas_half> || std::is_same_v<To, rocblas_bfloat16>)
+        {
+            host_vector<float> Y_float(dim_y * abs_incy);
+
+            for(int64_t i = 0; i < dim_y; i++)
+                Y_float[i * abs_incy] = static_cast<float>(y[i * abs_incy]);
+
+            cblas_sgemv(CblasColMajor,
+                        CBLAS_TRANSPOSE(transA),
+                        m,
+                        n,
+                        alpha,
+                        A_float,
+                        lda,
+                        X_float,
+                        incx,
+                        beta,
+                        Y_float,
+                        incy);
+
+            for(int64_t i = 0; i < dim_y; i++)
+                y[i * abs_incy] = (To)Y_float[i * abs_incy];
+        }
+        else
+        {
+            cblas_sgemv(CblasColMajor,
+                        CBLAS_TRANSPOSE(transA),
+                        m,
+                        n,
+                        alpha,
+                        A_float,
+                        lda,
+                        X_float,
+                        incx,
+                        beta,
+                        y,
+                        incy);
+        }
+    }
+    else if constexpr(std::is_same_v<Ti, float>)
+    {
+        // If not special case above, Ti == To == Ta for all other instantiations
+        cblas_sgemv(
+            CblasColMajor, CBLAS_TRANSPOSE(transA), m, n, alpha, A, lda, x, incx, beta, y, incy);
+    }
+    else if constexpr(std::is_same_v<Ti, double>)
+    {
+        cblas_dgemv(
+            CblasColMajor, CBLAS_TRANSPOSE(transA), m, n, alpha, A, lda, x, incx, beta, y, incy);
+    }
+    else if constexpr(std::is_same_v<Ti, rocblas_float_complex>)
+    {
+        cblas_cgemv(
+            CblasColMajor, CBLAS_TRANSPOSE(transA), m, n, &alpha, A, lda, x, incx, &beta, y, incy);
+    }
+    else if constexpr(std::is_same_v<Ti, rocblas_double_complex>)
+    {
+        cblas_zgemv(
+            CblasColMajor, CBLAS_TRANSPOSE(transA), m, n, &alpha, A, lda, x, incx, &beta, y, incy);
+    }
+}
+
+#define INSTANTIATE_CBLAS_GEMV_TEMPLATE(Ti_, To_, Ta_)                \
+    template void cblas_gemv<Ti_, To_, Ta_>(rocblas_operation transA, \
+                                            int64_t           m,      \
+                                            int64_t           n,      \
+                                            Ta_               alpha,  \
+                                            Ti_ * A,                  \
+                                            int64_t lda,              \
+                                            Ti_ * x,                  \
+                                            int64_t incx,             \
+                                            Ta_     beta,             \
+                                            To_ * y,                  \
+                                            int64_t incy);
+
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_half, rocblas_half, float)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_half, float, float)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_bfloat16, rocblas_bfloat16, float)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_bfloat16, float, float)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(float, float, float)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(double, double, double)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_float_complex, rocblas_float_complex, rocblas_float_complex)
+INSTANTIATE_CBLAS_GEMV_TEMPLATE(rocblas_double_complex,
+                                rocblas_double_complex,
+                                rocblas_double_complex)
+
+#undef INSTANTIATE_CBLAS_GEMV_TEMPLATE
+
 /*
  * ===========================================================================
  *    level 3 BLAS
@@ -417,19 +595,19 @@ template void cblas_dgmm<rocblas_complex_num<double>>(rocblas_side
 
 // geam
 template <typename T>
-inline T geam_conj_helper(const T& x)
+inline T rocblas_conj(const T& x)
 {
     return x;
 }
 
 template <>
-inline rocblas_float_complex geam_conj_helper(const rocblas_float_complex& x)
+inline rocblas_float_complex rocblas_conj(const rocblas_float_complex& x)
 {
     return std::conj(x);
 }
 
 template <>
-inline rocblas_double_complex geam_conj_helper(const rocblas_double_complex& x)
+inline rocblas_double_complex rocblas_conj(const rocblas_double_complex& x)
 {
     return std::conj(x);
 }
@@ -463,9 +641,9 @@ void cblas_geam_helper(rocblas_operation transA,
             T a_val = alpha ? A[i * inc1_A + j * inc2_A] : 0;
             T b_val = beta ? B[i * inc1_B + j * inc2_B] : 0;
             if(transA == rocblas_operation_conjugate_transpose)
-                a_val = geam_conj_helper(a_val);
+                a_val = rocblas_conj(a_val);
             if(transB == rocblas_operation_conjugate_transpose)
-                b_val = geam_conj_helper(b_val);
+                b_val = rocblas_conj(b_val);
             C[i + j * ldc] = alpha * a_val + beta * b_val;
         }
     }
@@ -866,6 +1044,133 @@ void cblas_gemm<int8_t, int32_t, int32_t>(rocblas_operation                    t
         C[i] = static_cast<int32_t>(C_double[i]);
 }
 
+//GEMMT
+template <typename T>
+void cblas_gemmt(rocblas_fill      uplo,
+                 rocblas_operation transA,
+                 rocblas_operation transB,
+                 int64_t           N,
+                 int64_t           K,
+                 T                 alpha,
+                 T*                A,
+                 int64_t           lda,
+                 T*                B,
+                 int64_t           ldb,
+                 T                 beta,
+                 T*                C,
+                 int64_t           ldc)
+{
+    int64_t inc1_A = transA == rocblas_operation_none ? 1 : lda;
+    int64_t inc2_A = transA == rocblas_operation_none ? lda : 1;
+    int64_t inc1_B = transB == rocblas_operation_none ? 1 : ldb;
+    int64_t inc2_B = transB == rocblas_operation_none ? ldb : 1;
+
+    if(uplo == rocblas_fill_upper)
+    {
+        //upper
+#ifdef _OPENMP
+#pragma omp parallel for
+#endif
+        for(int row = 0; row < N; row++)
+        {
+            for(int col = row; col < N; col++)
+            {
+                T t = T(0.0);
+                for(int elem = 0; elem < K; elem++)
+                {
+                    T a_val = alpha ? A[row * inc1_A + elem * inc2_A] : 0;
+                    T b_val = alpha ? B[elem * inc1_B + col * inc2_B] : 0;
+                    if(transA == rocblas_operation_conjugate_transpose)
+                        a_val = rocblas_conj(a_val);
+                    if(transB == rocblas_operation_conjugate_transpose)
+                        b_val = rocblas_conj(b_val);
+                    t += a_val * b_val;
+                }
+                C[row + col * ldc] = beta ? beta * C[row + col * ldc] + alpha * t : alpha * t;
+            }
+        }
+    }
+    else
+    {
+        //lower
+#ifdef _OPENMP
+#pragma omp parallel for
+#endif
+        for(int row = 0; row < N; row++)
+        {
+            for(int col = 0; col <= row; col++)
+            {
+                T t = T(0.0);
+                for(int elem = 0; elem < K; elem++)
+                {
+                    T a_val = alpha ? A[row * inc1_A + elem * inc2_A] : 0;
+                    T b_val = alpha ? B[elem * inc1_B + col * inc2_B] : 0;
+                    if(transA == rocblas_operation_conjugate_transpose)
+                        a_val = rocblas_conj(a_val);
+                    if(transB == rocblas_operation_conjugate_transpose)
+                        b_val = rocblas_conj(b_val);
+                    t += a_val * b_val;
+                }
+                C[row + col * ldc] = beta ? beta * C[row + col * ldc] + alpha * t : alpha * t;
+            }
+        }
+    }
+}
+
+//gemmt instantiations
+template void cblas_gemmt<float>(rocblas_fill      uplo,
+                                 rocblas_operation transA,
+                                 rocblas_operation transB,
+                                 int64_t           N,
+                                 int64_t           K,
+                                 float             alpha,
+                                 float*            A,
+                                 int64_t           lda,
+                                 float*            B,
+                                 int64_t           ldb,
+                                 float             beta,
+                                 float*            C,
+                                 int64_t           ldc);
+template void cblas_gemmt<double>(rocblas_fill      uplo,
+                                  rocblas_operation transA,
+                                  rocblas_operation transB,
+                                  int64_t           N,
+                                  int64_t           K,
+                                  double            alpha,
+                                  double*           A,
+                                  int64_t           lda,
+                                  double*           B,
+                                  int64_t           ldb,
+                                  double            beta,
+                                  double*           C,
+                                  int64_t           ldc);
+template void cblas_gemmt<rocblas_complex_num<float>>(rocblas_fill                uplo,
+                                                      rocblas_operation           transA,
+                                                      rocblas_operation           transB,
+                                                      int64_t                     N,
+                                                      int64_t                     K,
+                                                      rocblas_complex_num<float>  alpha,
+                                                      rocblas_complex_num<float>* A,
+                                                      int64_t                     lda,
+                                                      rocblas_complex_num<float>* B,
+                                                      int64_t                     ldb,
+                                                      rocblas_complex_num<float>  beta,
+                                                      rocblas_complex_num<float>* C,
+                                                      int64_t                     ldc);
+template void cblas_gemmt<rocblas_complex_num<double>>(rocblas_fill                 uplo,
+                                                       rocblas_operation            transA,
+                                                       rocblas_operation            transB,
+                                                       int64_t                      N,
+                                                       int64_t                      K,
+                                                       rocblas_complex_num<double>  alpha,
+                                                       rocblas_complex_num<double>* A,
+                                                       int64_t                      lda,
+                                                       rocblas_complex_num<double>* B,
+                                                       int64_t                      ldb,
+                                                       rocblas_complex_num<double>  beta,
+                                                       rocblas_complex_num<double>* C,
+                                                       int64_t                      ldc);
+
 template <typename T>
 void cblas_geam_min_plus(rocblas_operation transA,
                          rocblas_operation transB,
