@@ -210,15 +210,13 @@ def get_arguments(doc):
 
 def setkey_product(test, key, vals):
     """Helper for setdefaults. Tests that all values in vals is present
-    in test, if so then sets test[key] to product of all test[vals]."""
+    in test, if so then sets test[key] to positive product of all test[vals].
+    This will require changes if negative strides need to be computed."""
     if all(x in test for x in vals):
         result = 1
         for x in vals:
-            if x in ('incx', 'incy'):
-                result *= abs(test[x])
-            else:
-                result *= test[x]
-        test[key] = int(result)
+            result *= test[x]
+        test[key] = int(abs(result))
 
 
 def setdefaults(test):
@@ -244,19 +242,23 @@ def setdefaults(test):
             test.setdefault('stride_c', int(test['stride_scale']) * 5)
 
     elif test['function'] in ('tpmv_strided_batched'):
-        setkey_product(test, 'stride_x', ['M', 'incx', 'stride_scale'])
-# Let's use M * M (> (M * (M+1)) / 2) as a 'stride' size for the packed format.
-        setkey_product(test, 'stride_a', ['M', 'M', 'stride_scale'])
+        setkey_product(test, 'stride_x', ['N', 'incx', 'stride_scale'])
+        # Let's use N * N (> (N * (N+1)) / 2) as a 'stride' size for the packed format.
+        setkey_product(test, 'stride_a', ['N', 'N', 'stride_scale'])
 
     elif test['function'] in ('trmv_strided_batched'):
-        setkey_product(test, 'stride_x', ['M', 'incx', 'stride_scale'])
-        setkey_product(test, 'stride_a', ['M', 'lda', 'stride_scale'])
+        setkey_product(test, 'stride_x', ['N', 'incx', 'stride_scale'])
+        setkey_product(test, 'stride_a', ['N', 'lda', 'stride_scale'])
+
+    elif test['function'] in ('trsv_strided_batched'):
+        setkey_product(test, 'stride_x', ['N', 'incx', 'stride_scale'])
+        setkey_product(test, 'stride_a', ['lda', 'N', 'stride_scale'])
 
     elif test['function'] in ('gemv_strided_batched', 'gbmv_strided_batched',
                               'ger_strided_batched', 'geru_strided_batched',
-                              'gerc_strided_batched', 'trsv_strided_batched'):
+                              'gerc_strided_batched'):
         if test['function'] in ('ger_strided_batched', 'geru_strided_batched',
-                                'gerc_strided_batched', 'trsv_strided_batched'
+                                'gerc_strided_batched',
                                 ) or test['transA'] in ('T', 'C'):
             setkey_product(test, 'stride_x', ['M', 'incx', 'stride_scale'])
             setkey_product(test, 'stride_y', ['N', 'incy', 'stride_scale'])
@@ -265,8 +267,6 @@ def setdefaults(test):
             setkey_product(test, 'stride_y', ['M', 'incy', 'stride_scale'])
         if test['function'] in ('gbmv_strided_batched'):
             setkey_product(test, 'stride_a', ['lda', 'N', 'stride_scale'])
-        if test['function'] in ('trsv_strided_batched'):
-            setkey_product(test, 'stride_a', ['lda', 'M', 'stride_scale'])
 
     elif test['function'] in ('hemv_strided_batched', 'hbmv_strided_batched',
                               'sbmv_strided_batched'):
@@ -336,7 +336,7 @@ def setdefaults(test):
         else:
             setkey_product(test, 'stride_b', ['M', 'ldb', 'stride_scale'])
 
-    elif test['function'] in ('trmm_strided_batched', 'trmm_outofplace_strided_batched'):
+    elif test['function'] in ('trmm_strided_batched'):
         setkey_product(test, 'stride_b', ['N', 'ldb', 'stride_scale'])
         setkey_product(test, 'stride_c', ['N', 'ldc', 'stride_scale'])
 
@@ -355,11 +355,11 @@ def setdefaults(test):
             setkey_product(test, 'stride_a', ['N', 'lda', 'stride_scale'])
 
     elif test['function'] in ('tbmv_strided_batched'):
-        if all([x in test for x in ('M', 'lda', 'stride_scale')]):
-            ldM = int(test['M'] * test['lda'] * test['stride_scale'])
-            test.setdefault('stride_a', ldM)
-        if all([x in test for x in ('M', 'incx', 'stride_scale')]):
-            ldx = int(test['M'] * abs(test['incx']) * test['stride_scale'])
+        if all([x in test for x in ('N', 'lda', 'stride_scale')]):
+            ldN = int(test['N'] * test['lda'] * test['stride_scale'])
+            test.setdefault('stride_a', ldN)
+        if all([x in test for x in ('N', 'incx', 'stride_scale')]):
+            ldx = int(test['N'] * abs(test['incx']) * test['stride_scale'])
             test.setdefault('stride_x', ldx)
 
     elif test['function'] in ('tbsv_strided_batched'):
