@@ -40,21 +40,22 @@
 template <typename T>
 void testing_trmm_bad_arg(const Arguments& arg)
 {
-#ifdef ROCBLAS_V3
-    rocblas_cout
-        << "WARNING: For V3 run trmm_outofplace tests, in place trmm tests only run for V2.\n";
-#else
     auto rocblas_trmm_fn = arg.api == FORTRAN ? rocblas_trmm<T, true> : rocblas_trmm<T, false>;
+    // trmm has both inplace and outofplace versions.
+    // inplace == true for inplace, inplace == false for outofplace
+    bool inplace = !arg.outofplace;
 
     for(auto pointer_mode : {rocblas_pointer_mode_host, rocblas_pointer_mode_device})
     {
         rocblas_local_handle handle{arg};
         CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, pointer_mode));
 
-        const rocblas_int M   = 100;
-        const rocblas_int N   = 100;
-        const rocblas_int lda = 100;
-        const rocblas_int ldb = 100;
+        const rocblas_int M     = 100;
+        const rocblas_int N     = 100;
+        const rocblas_int lda   = 100;
+        const rocblas_int ldb   = 100;
+        const rocblas_int ldc   = 100;
+        const rocblas_int ldOut = inplace ? ldb : ldc;
 
         device_vector<T> alpha_d(1), zero_d(1);
 
@@ -82,15 +83,35 @@ void testing_trmm_bad_arg(const Arguments& arg)
         device_matrix<T> dA(K, K, lda);
         device_matrix<T> dB(M, N, ldb);
 
+        rocblas_int dC_M   = inplace ? 1 : M;
+        rocblas_int dC_N   = inplace ? 1 : N;
+        rocblas_int dC_ldc = inplace ? 1 : ldc;
+
+        device_matrix<T> dC(dC_M, dC_N, dC_ldc);
+
+        device_matrix<T>* dOut = inplace ? &dB : &dC;
+
         // Check device memory allocation
         CHECK_DEVICE_ALLOCATION(dA.memcheck());
         CHECK_DEVICE_ALLOCATION(dB.memcheck());
+        CHECK_DEVICE_ALLOCATION(dC.memcheck());
 
         // check for invalid enum
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(
-                handle, rocblas_side_both, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb),
-            rocblas_status_invalid_value);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              rocblas_side_both,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              N,
+                                              alpha,
+                                              dA,
+                                              lda,
+                                              dB,
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
+                              rocblas_status_invalid_value);
 
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
                                               side,
@@ -103,7 +124,9 @@ void testing_trmm_bad_arg(const Arguments& arg)
                                               dA,
                                               lda,
                                               dB,
-                                              ldb),
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
                               rocblas_status_invalid_value);
 
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
@@ -117,7 +140,9 @@ void testing_trmm_bad_arg(const Arguments& arg)
                                               dA,
                                               lda,
                                               dB,
-                                              ldb),
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
                               rocblas_status_invalid_value);
 
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
@@ -131,83 +156,168 @@ void testing_trmm_bad_arg(const Arguments& arg)
                                               dA,
                                               lda,
                                               dB,
-                                              ldb),
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
                               rocblas_status_invalid_value);
 
         // check for invalid size
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, -1, N, alpha, dA, lda, dB, ldb),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, -1, N, alpha, dA, lda, dB, ldb, *dOut, ldOut),
             rocblas_status_invalid_size);
 
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, -1, alpha, dA, lda, dB, ldb),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, -1, alpha, dA, lda, dB, ldb, *dOut, ldOut),
             rocblas_status_invalid_size);
 
         // check for invalid leading dimension
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, M - 1),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, M - 1, *dOut, ldOut),
             rocblas_status_invalid_size);
 
         EXPECT_ROCBLAS_STATUS(
             rocblas_trmm_fn(
-                handle, rocblas_side_left, uplo, transA, diag, M, N, alpha, dA, M - 1, dB, ldb),
+                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb, *dOut, M - 1),
             rocblas_status_invalid_size);
 
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(
-                handle, rocblas_side_right, uplo, transA, diag, M, N, alpha, dA, N - 1, dB, ldb),
-            rocblas_status_invalid_size);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              rocblas_side_left,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              N,
+                                              alpha,
+                                              dA,
+                                              M - 1,
+                                              dB,
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
+                              rocblas_status_invalid_size);
+
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              rocblas_side_right,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              N,
+                                              alpha,
+                                              dA,
+                                              N - 1,
+                                              dB,
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
+                              rocblas_status_invalid_size);
 
         // check that nullpointer gives rocblas_status_invalid_handle or rocblas_status_invalid_pointer
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(nullptr, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb),
+            rocblas_trmm_fn(
+                nullptr, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb, *dOut, ldOut),
             rocblas_status_invalid_handle);
 
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, nullptr, dA, lda, dB, ldb),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, nullptr, dA, lda, dB, ldb, *dOut, ldOut),
             rocblas_status_invalid_pointer);
 
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, alpha, nullptr, lda, dB, ldb),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, alpha, nullptr, lda, dB, ldb, *dOut, ldOut),
             rocblas_status_invalid_pointer);
 
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, alpha, dA, lda, nullptr, ldb),
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, nullptr, ldb, *dOut, ldOut),
             rocblas_status_invalid_pointer);
 
-        // quick return: If alpha==0, then A can be nullptr without error
         EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, zero, nullptr, lda, dB, ldb),
-            rocblas_status_success);
+            rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb, nullptr, ldOut),
+            rocblas_status_invalid_pointer);
+
+        // quick return: If alpha==0, then A and B can be nullptr without error
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              side,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              N,
+                                              zero,
+                                              nullptr,
+                                              lda,
+                                              nullptr,
+                                              ldb,
+                                              *dOut,
+                                              ldOut),
+                              rocblas_status_success);
 
         // quick return: If M==0, then all pointers can be nullptr without error
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(
-                handle, side, uplo, transA, diag, 0, N, nullptr, nullptr, lda, nullptr, ldb),
-            rocblas_status_success);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              side,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              0,
+                                              N,
+                                              nullptr,
+                                              nullptr,
+                                              lda,
+                                              nullptr,
+                                              ldb,
+                                              nullptr,
+                                              ldOut),
+                              rocblas_status_success);
 
         // quick return: If N==0, then all pointers can be nullptr without error
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(
-                handle, side, uplo, transA, diag, M, 0, nullptr, nullptr, lda, nullptr, ldb),
-            rocblas_status_success);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              side,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              0,
+                                              nullptr,
+                                              nullptr,
+                                              lda,
+                                              nullptr,
+                                              ldb,
+                                              nullptr,
+                                              ldOut),
+                              rocblas_status_success);
+        // in-place only checks
+        if(inplace)
+        {
+            // if inplace, must have ldb == ldc
+            EXPECT_ROCBLAS_STATUS(
+                rocblas_trmm_fn(
+                    handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb, dB, ldb + 1),
+                rocblas_status_invalid_value);
+        }
     }
-#endif // ROCBLAS_V3
 }
 
 template <typename T>
 void testing_trmm(const Arguments& arg)
 {
-#ifdef ROCBLAS_V3
-    rocblas_cout
-        << "WARNING: For V3 run trmm_outofplace tests, in place trmm tests only run for V2.\n";
-#else
     auto rocblas_trmm_fn = arg.api == FORTRAN ? rocblas_trmm<T, true> : rocblas_trmm<T, false>;
 
-    rocblas_int M   = arg.M;
-    rocblas_int N   = arg.N;
-    rocblas_int lda = arg.lda;
-    rocblas_int ldb = arg.ldb;
+    // trmm has both inplace and outofplace versions.
+    // inplace == true for inplace, inplace == false for outofplace
+    bool inplace = !arg.outofplace;
+
+    rocblas_int M     = arg.M;
+    rocblas_int N     = arg.N;
+    rocblas_int lda   = arg.lda;
+    rocblas_int ldb   = arg.ldb;
+    rocblas_int ldc   = arg.ldc;
+    rocblas_int ldOut = inplace ? ldb : ldc;
 
     char char_side   = arg.side;
     char char_uplo   = arg.uplo;
@@ -225,13 +335,24 @@ void testing_trmm(const Arguments& arg)
     rocblas_local_handle handle{arg};
 
     // ensure invalid sizes and quick return checked before pointer check
-    bool invalid_size = M < 0 || N < 0 || lda < K || ldb < M;
+    bool invalid_size = M < 0 || N < 0 || lda < K || ldb < M || ldc < M;
     if(M == 0 || N == 0 || invalid_size)
     {
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_fn(
-                handle, side, uplo, transA, diag, M, N, nullptr, nullptr, lda, nullptr, ldb),
-            invalid_size ? rocblas_status_invalid_size : rocblas_status_success);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                              side,
+                                              uplo,
+                                              transA,
+                                              diag,
+                                              M,
+                                              N,
+                                              nullptr,
+                                              nullptr,
+                                              lda,
+                                              nullptr,
+                                              ldb,
+                                              nullptr,
+                                              ldc),
+                              invalid_size ? rocblas_status_invalid_size : rocblas_status_success);
         return;
     }
 
@@ -239,11 +360,13 @@ void testing_trmm(const Arguments& arg)
     // Allocate host memory
     host_matrix<T> hA(K, K, lda);
     host_matrix<T> hB(M, N, ldb);
-    host_matrix<T> hB_gold(M, N, ldb);
+    host_matrix<T> hC(M, N, ldc);
+    host_matrix<T> hC_gold(M, N, ldc);
 
     // Allocate device memory
     device_matrix<T> dA(K, K, lda);
     device_matrix<T> dB(M, N, ldb);
+
     device_vector<T> alpha_d(1);
 
     // Check device memory allocation
@@ -256,13 +379,53 @@ void testing_trmm(const Arguments& arg)
         hA, arg, rocblas_client_alpha_sets_nan, rocblas_client_triangular_matrix, true);
     rocblas_init_matrix(
         hB, arg, rocblas_client_alpha_sets_nan, rocblas_client_general_matrix, false, true);
-
-    hB_gold = hB; // hB_gold <- B
+    rocblas_init_matrix(hC, arg, rocblas_client_alpha_sets_nan, rocblas_client_general_matrix);
 
     // copy data from CPU to device
     CHECK_HIP_ERROR(dA.transfer_from(hA));
     CHECK_HIP_ERROR(dB.transfer_from(hB));
 
+    // inplace    trmm is given by B <- alpha * op(A) * B so  matrix C is not used
+    // outofplace trmm is given by C <- alpha * op(A) * B and matrix C is used
+    rocblas_int dC_M   = inplace ? 1 : M;
+    rocblas_int dC_N   = inplace ? 1 : N;
+    rocblas_int dC_ldc = inplace ? 1 : ldc;
+
+    device_matrix<T> dC(dC_M, dC_N, dC_ldc);
+    CHECK_DEVICE_ALLOCATION(dC.memcheck());
+
+    device_matrix<T>* dOut = inplace ? &dB : &dC;
+
+    if(inplace)
+    {
+        if(ldb != ldc)
+        {
+            EXPECT_ROCBLAS_STATUS(rocblas_trmm_fn(handle,
+                                                  side,
+                                                  uplo,
+                                                  transA,
+                                                  diag,
+                                                  M,
+                                                  N,
+                                                  &h_alpha_T,
+                                                  dA,
+                                                  lda,
+                                                  dB,
+                                                  ldb,
+                                                  *dOut,
+                                                  ldc),
+                                  rocblas_status_invalid_value);
+            return;
+        }
+
+        hC_gold = hB;
+    }
+    else
+    {
+        CHECK_HIP_ERROR(dC.transfer_from(hC));
+        hC_gold = hC;
+    }
+
     double gpu_time_used, cpu_time_used;
     gpu_time_used = cpu_time_used = 0.0;
     double err_host = 0.0, err_device = 0.0;
@@ -271,31 +434,44 @@ void testing_trmm(const Arguments& arg)
     {
         if(arg.pointer_mode_host)
         {
-            // calculate dB <- A^(-1) B   rocblas_device_pointer_host
             CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_host));
             handle.pre_test(arg);
-            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(
-                handle, side, uplo, transA, diag, M, N, &h_alpha_T, dA, lda, dB, ldb));
+            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(handle,
+                                                side,
+                                                uplo,
+                                                transA,
+                                                diag,
+                                                M,
+                                                N,
+                                                &h_alpha_T,
+                                                dA,
+                                                lda,
+                                                dB,
+                                                ldb,
+                                                *dOut,
+                                                ldOut));
             handle.post_test(arg);
-            CHECK_HIP_ERROR(hB.transfer_from(dB));
+            CHECK_HIP_ERROR(hC.transfer_from(*dOut));
         }
 
         if(arg.pointer_mode_device)
         {
-            // calculate dB <- A^(-1) B   rocblas_device_pointer_device
+            CHECK_HIP_ERROR((*dOut).transfer_from(hC_gold));
             CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_device));
-            CHECK_HIP_ERROR(dB.transfer_from(hB_gold));
             CHECK_HIP_ERROR(hipMemcpy(alpha_d, &h_alpha_T, sizeof(T), hipMemcpyHostToDevice));
 
-            CHECK_ROCBLAS_ERROR(
-                rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, alpha_d, dA, lda, dB, ldb));
+            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(
+                handle, side, uplo, transA, diag, M, N, alpha_d, dA, lda, dB, ldb, *dOut, ldOut));
         }
 
         // CPU BLAS
         cpu_time_used = get_time_us_no_sync();
-        cblas_trmm<T>(side, uplo, transA, diag, M, N, h_alpha_T, hA, lda, hB_gold, ldb);
+        cblas_trmm<T>(side, uplo, transA, diag, M, N, h_alpha_T, hA, lda, hB, ldb);
         cpu_time_used = get_time_us_no_sync() - cpu_time_used;
 
+        // copy B matrix into C matrix
+        copy_matrix_with_different_leading_dimensions(hB, hC_gold);
+
         if(arg.pointer_mode_host)
         {
             if(arg.unit_check)
@@ -305,23 +481,21 @@ void testing_trmm(const Arguments& arg)
                     // For large K, rocblas_half tends to diverge proportional to K
                     // Tolerance is slightly greater than 1 / 1024.0
                     const double tol = K * sum_error_tolerance<T>;
-                    near_check_general<T>(M, N, ldb, hB_gold, hB, tol);
+                    near_check_general<T>(M, N, ldc, hC_gold, hC, tol);
                 }
                 else
                 {
-                    unit_check_general<T>(M, N, ldb, hB_gold, hB);
+                    unit_check_general<T>(M, N, ldc, hC_gold, hC);
                 }
             }
-
             if(arg.norm_check)
             {
-                err_host = std::abs(norm_check_general<T>('F', M, N, ldb, hB_gold, hB));
+                err_host = std::abs(norm_check_general<T>('F', M, N, ldc, hC_gold, hC));
             }
         }
         if(arg.pointer_mode_device)
         {
-            // fetch GPU
-            CHECK_HIP_ERROR(hB.transfer_from(dB));
+            CHECK_HIP_ERROR(hC.transfer_from(*dOut));
 
             if(arg.unit_check)
             {
@@ -330,17 +504,16 @@ void testing_trmm(const Arguments& arg)
                     // For large K, rocblas_half tends to diverge proportional to K
                     // Tolerance is slightly greater than 1 / 1024.0
                     const double tol = K * sum_error_tolerance<T>;
-                    near_check_general<T>(M, N, ldb, hB_gold, hB, tol);
+                    near_check_general<T>(M, N, ldc, hC_gold, hC, tol);
                 }
                 else
                 {
-                    unit_check_general<T>(M, N, ldb, hB_gold, hB);
+                    unit_check_general<T>(M, N, ldc, hC_gold, hC);
                 }
             }
-
             if(arg.norm_check)
             {
-                err_device = std::abs(norm_check_general<T>('F', M, N, ldb, hB_gold, hB));
+                err_device = std::abs(norm_check_general<T>('F', M, N, ldc, hC_gold, hC));
             }
         }
     }
@@ -354,8 +527,20 @@ void testing_trmm(const Arguments& arg)
 
         for(int i = 0; i < number_cold_calls; i++)
         {
-            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(
-                handle, side, uplo, transA, diag, M, N, &h_alpha_T, dA, lda, dB, ldb));
+            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(handle,
+                                                side,
+                                                uplo,
+                                                transA,
+                                                diag,
+                                                M,
+                                                N,
+                                                &h_alpha_T,
+                                                dA,
+                                                lda,
+                                                dB,
+                                                ldb,
+                                                *dOut,
+                                                ldOut));
         }
 
         hipStream_t stream;
@@ -363,11 +548,34 @@ void testing_trmm(const Arguments& arg)
         gpu_time_used = get_time_us_sync(stream); // in microseconds
         for(int i = 0; i < number_hot_calls; i++)
         {
-            rocblas_trmm_fn(handle, side, uplo, transA, diag, M, N, &h_alpha_T, dA, lda, dB, ldb);
+            CHECK_ROCBLAS_ERROR(rocblas_trmm_fn(handle,
+                                                side,
+                                                uplo,
+                                                transA,
+                                                diag,
+                                                M,
+                                                N,
+                                                &h_alpha_T,
+                                                dA,
+                                                lda,
+                                                dB,
+                                                ldb,
+                                                *dOut,
+                                                ldOut));
         }
         gpu_time_used = get_time_us_sync(stream) - gpu_time_used;
 
-        ArgumentModel<e_side, e_uplo, e_transA, e_diag, e_M, e_N, e_alpha, e_lda, e_ldb>{}
+        ArgumentModel<e_side,
+                      e_uplo,
+                      e_transA,
+                      e_diag,
+                      e_M,
+                      e_N,
+                      e_alpha,
+                      e_lda,
+                      e_ldb,
+                      e_ldc,
+                      e_outofplace>{}
             .log_args<T>(rocblas_cout,
                          arg,
                          gpu_time_used,
@@ -377,5 +585,4 @@ void testing_trmm(const Arguments& arg)
                          err_host,
                          err_device);
     }
-#endif // ROCBLAS_V3
 }
