@@ -40,12 +40,11 @@
 template <typename T>
 void testing_trmm_batched_bad_arg(const Arguments& arg)
 {
-#ifdef ROCBLAS_V3
-    rocblas_cout << "WARNING: For V3 run trmm_outofplace_batched tests, in place trmm_batched "
-                    "tests only run for V2.\n";
-#else
     auto rocblas_trmm_batched_fn
         = arg.api == FORTRAN ? rocblas_trmm_batched<T, true> : rocblas_trmm_batched<T, false>;
+    // trmm has both inplace and outofplace versions.
+    // inplace == true for inplace, inplace == false for outofplace
+    bool inplace = !arg.outofplace;
 
     for(auto pointer_mode : {rocblas_pointer_mode_host, rocblas_pointer_mode_device})
     {
@@ -53,9 +52,11 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
         CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, pointer_mode));
 
         const rocblas_int M           = 100;
-        const rocblas_int N           = 100;
-        const rocblas_int lda         = 100;
-        const rocblas_int ldb         = 100;
+        const rocblas_int N           = 101;
+        const rocblas_int lda         = 101;
+        const rocblas_int ldb         = 101;
+        const rocblas_int ldc         = 101;
+        const rocblas_int ldOut       = inplace ? ldb : ldc;
         const rocblas_int batch_count = 2;
 
         device_vector<T> alpha_d(1), zero_d(1);
@@ -84,9 +85,18 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
         device_batch_matrix<T> dA(K, K, lda, batch_count);
         device_batch_matrix<T> dB(M, N, ldb, batch_count);
 
+        rocblas_int dC_M   = inplace ? 1 : M;
+        rocblas_int dC_N   = inplace ? 1 : N;
+        rocblas_int dC_ldc = inplace ? 1 : ldc;
+
+        device_batch_matrix<T> dC(dC_M, dC_N, dC_ldc, batch_count);
+
         // Check device memory allocation
         CHECK_DEVICE_ALLOCATION(dA.memcheck());
         CHECK_DEVICE_ALLOCATION(dB.memcheck());
+        CHECK_DEVICE_ALLOCATION(dC.memcheck());
+
+        device_batch_matrix<T>* dOut = inplace ? &dB : &dC;
 
         // check for invalid enum
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
@@ -97,10 +107,12 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       lda,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_value);
 
@@ -112,10 +124,12 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       lda,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_value);
 
@@ -127,10 +141,12 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       lda,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_value);
 
@@ -142,29 +158,84 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       lda,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_value);
 
         // check for invalid size
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, -1, N, alpha, dA, lda, dB, ldb, batch_count),
-            rocblas_status_invalid_size);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      -1,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_size);
 
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, -1, alpha, dA, lda, dB, ldb, batch_count),
-            rocblas_status_invalid_size);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      -1,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_size);
 
         // check for invalid leading dimension
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, M - 1, batch_count),
-            rocblas_status_invalid_size);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      M - 1,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_size);
+
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      M - 1,
+                                                      batch_count),
+                              rocblas_status_invalid_size);
 
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
                                                       rocblas_side_left,
@@ -174,10 +245,12 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       M - 1,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_size);
 
@@ -189,35 +262,102 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       M,
                                                       N,
                                                       alpha,
-                                                      dA,
+                                                      dA.ptr_on_device(),
                                                       N - 1,
-                                                      dB,
+                                                      dB.ptr_on_device(),
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_invalid_size);
 
         // check that nullpointer gives rocblas_status_invalid_handle or rocblas_status_invalid_pointer
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                nullptr, side, uplo, transA, diag, M, N, alpha, dA, lda, dB, ldb, batch_count),
-            rocblas_status_invalid_handle);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(nullptr,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_handle);
 
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, N, nullptr, dA, lda, dB, ldb, batch_count),
-            rocblas_status_invalid_pointer);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      nullptr,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_pointer);
 
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, N, alpha, nullptr, lda, dB, ldb, batch_count),
-            rocblas_status_invalid_pointer);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      nullptr,
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_pointer);
 
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, N, alpha, dA, lda, nullptr, ldb, batch_count),
-            rocblas_status_invalid_pointer);
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      nullptr,
+                                                      ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_pointer);
 
-        // If alpha==0, A may be nullptr without error
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      alpha,
+                                                      dA.ptr_on_device(),
+                                                      lda,
+                                                      dB.ptr_on_device(),
+                                                      ldb,
+                                                      nullptr,
+                                                      ldOut,
+                                                      batch_count),
+                              rocblas_status_invalid_pointer);
+
+        // quick return: If alpha==0, then A and B can be nullptr without error
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
                                                       side,
                                                       uplo,
@@ -228,12 +368,14 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       zero,
                                                       nullptr,
                                                       lda,
-                                                      dB.ptr_on_device(),
+                                                      nullptr,
                                                       ldb,
+                                                      (*dOut).ptr_on_device(),
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_success);
 
-        // quick return: If M==0, all pointers may be nullptr without error
+        // quick return: If M==0, then all pointers can be nullptr without error
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
                                                       side,
                                                       uplo,
@@ -246,10 +388,12 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       lda,
                                                       nullptr,
                                                       ldb,
+                                                      nullptr,
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_success);
 
-        // quick return: If N==0, all pointers may be nullptr without error
+        // quick return: If N==0, then all pointers can be nullptr without error
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
                                                       side,
                                                       uplo,
@@ -262,28 +406,61 @@ void testing_trmm_batched_bad_arg(const Arguments& arg)
                                                       lda,
                                                       nullptr,
                                                       ldb,
+                                                      nullptr,
+                                                      ldOut,
                                                       batch_count),
                               rocblas_status_success);
 
-        // quick return: If batch_count==0, all pointers may be nullptr without error
-        EXPECT_ROCBLAS_STATUS(
-            rocblas_trmm_batched_fn(
-                handle, side, uplo, transA, diag, M, N, nullptr, nullptr, lda, nullptr, ldb, 0),
-            rocblas_status_success);
+        // quick return: If batch_count==0, then all pointers can be nullptr without error
+        EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                      side,
+                                                      uplo,
+                                                      transA,
+                                                      diag,
+                                                      M,
+                                                      N,
+                                                      nullptr,
+                                                      nullptr,
+                                                      lda,
+                                                      nullptr,
+                                                      ldb,
+                                                      nullptr,
+                                                      ldOut,
+                                                      0),
+                              rocblas_status_success);
+        if(inplace)
+        {
+            // if inplace, must have ldb == ldc
+            EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                          side,
+                                                          uplo,
+                                                          transA,
+                                                          diag,
+                                                          M,
+                                                          N,
+                                                          alpha,
+                                                          dA.ptr_on_device(),
+                                                          lda,
+                                                          dB.ptr_on_device(),
+                                                          ldb,
+                                                          dB.ptr_on_device(),
+                                                          ldb + 1,
+                                                          batch_count),
+                                  rocblas_status_invalid_value);
+        }
     }
-#endif // ROCBLAS_V3
 }
 
 template <typename T>
 void testing_trmm_batched(const Arguments& arg)
 {
-#ifdef ROCBLAS_V3
-    rocblas_cout << "WARNING: For V3 run trmm_outofplace_batched tests, in place trmm_batched "
-                    "tests only run for V2.\n";
-#else
     auto rocblas_trmm_batched_fn
         = arg.api == FORTRAN ? rocblas_trmm_batched<T, true> : rocblas_trmm_batched<T, false>;
 
+    // trmm has both inplace and outofplace versions.
+    // inplace == true for inplace, inplace == false for outofplace
+    bool inplace = !arg.outofplace;
+
     bool nantest = rocblas_isnan(arg.alpha) || rocblas_isnan(arg.alphai);
     if(!std::is_same_v<
            T,
@@ -295,6 +472,8 @@ void testing_trmm_batched(const Arguments& arg)
     rocblas_int          N           = arg.N;
     rocblas_int          lda         = arg.lda;
     rocblas_int          ldb         = arg.ldb;
+    rocblas_int          ldc         = arg.ldc;
+    rocblas_int          ldOut       = inplace ? ldb : ldc;
     rocblas_int          batch_count = arg.batch_count;
 
     char char_side   = arg.side;
@@ -311,7 +490,7 @@ void testing_trmm_batched(const Arguments& arg)
     rocblas_int K = side == rocblas_side_left ? M : N;
 
     // ensure invalid sizes and quick return checked before pointer check
-    bool invalid_size = M < 0 || N < 0 || lda < K || ldb < M || batch_count < 0;
+    bool invalid_size = M < 0 || N < 0 || lda < K || ldb < M || ldc < M || batch_count < 0;
     if(M == 0 || N == 0 || batch_count == 0 || invalid_size)
     {
         EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
@@ -326,25 +505,33 @@ void testing_trmm_batched(const Arguments& arg)
                                                       lda,
                                                       nullptr,
                                                       ldb,
+                                                      nullptr,
+                                                      ldc,
                                                       batch_count),
                               invalid_size ? rocblas_status_invalid_size : rocblas_status_success);
         return;
     }
 
+    double gpu_time_used, cpu_time_used;
+    gpu_time_used = cpu_time_used = 0.0;
+    double err_host = 0.0, err_device = 0.0;
+
     // Naming: `h` is in CPU (host) memory(eg hA), `d` is in GPU (device) memory (eg dA).
     // Allocate host memory
     host_batch_matrix<T> hA(K, K, lda, batch_count);
     host_batch_matrix<T> hB(M, N, ldb, batch_count);
-    host_batch_matrix<T> hB_gold(M, N, ldb, batch_count);
+    host_batch_matrix<T> hC(M, N, ldc, batch_count);
+    host_batch_matrix<T> hC_gold(M, N, ldc, batch_count);
     host_vector<T>       h_alpha(1);
 
+    //  Initialize data on CPU
+    h_alpha[0] = alpha;
+
     // Check host memory allocation
     CHECK_HIP_ERROR(hA.memcheck());
     CHECK_HIP_ERROR(hB.memcheck());
-    CHECK_HIP_ERROR(hB_gold.memcheck());
-
-    //  initialize data on CPU
-    h_alpha[0] = alpha;
+    CHECK_HIP_ERROR(hC.memcheck());
+    CHECK_HIP_ERROR(hC_gold.memcheck());
 
     // Allocate device memory
     device_batch_matrix<T> dA(K, K, lda, batch_count);
@@ -361,22 +548,60 @@ void testing_trmm_batched(const Arguments& arg)
         hA, arg, rocblas_client_alpha_sets_nan, rocblas_client_triangular_matrix, true);
     rocblas_init_matrix(
         hB, arg, rocblas_client_alpha_sets_nan, rocblas_client_general_matrix, false, true);
+    rocblas_init_matrix(hC, arg, rocblas_client_alpha_sets_nan, rocblas_client_general_matrix);
 
-    hB_gold.copy_from(hB);
+    hC_gold.copy_from(hC);
 
     // copy data from CPU to device
     CHECK_HIP_ERROR(dA.transfer_from(hA));
     CHECK_HIP_ERROR(dB.transfer_from(hB));
 
-    double gpu_time_used, cpu_time_used;
-    gpu_time_used = cpu_time_used = 0.0;
-    double err_host = 0.0, err_device = 0.0;
+    // inplace    trmm is given by B <- alpha * op(A) * B so  matrix C is not used
+    // outofplace trmm is given by C <- alpha * op(A) * B and matrix C is used
+    rocblas_int dC_M   = inplace ? 1 : M;
+    rocblas_int dC_N   = inplace ? 1 : N;
+    rocblas_int dC_ldc = inplace ? 1 : ldc;
+
+    device_batch_matrix<T> dC(dC_M, dC_N, dC_ldc, batch_count);
+    CHECK_DEVICE_ALLOCATION(dC.memcheck());
+
+    device_batch_matrix<T>* dOut = inplace ? &dB : &dC;
+
+    if(inplace)
+    {
+        // if ldc != ldb inplace returns rocblas_status_invalid_value
+        if(ldb != ldc)
+        {
+            EXPECT_ROCBLAS_STATUS(rocblas_trmm_batched_fn(handle,
+                                                          side,
+                                                          uplo,
+                                                          transA,
+                                                          diag,
+                                                          M,
+                                                          N,
+                                                          &h_alpha[0],
+                                                          dA.ptr_on_device(),
+                                                          lda,
+                                                          dB.ptr_on_device(),
+                                                          ldb,
+                                                          (*dOut).ptr_on_device(),
+                                                          ldc,
+                                                          batch_count),
+                                  rocblas_status_invalid_value);
+            return;
+        }
+        hC_gold.copy_from(hB);
+    }
+    else
+    {
+        CHECK_HIP_ERROR(dC.transfer_from(hC));
+        hC_gold.copy_from(hC);
+    }
 
     if(arg.unit_check || arg.norm_check)
     {
         if(arg.pointer_mode_host)
         {
-            // calculate dB <- A^(-1) B   rocblas_device_pointer_host
             CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_host));
             handle.pre_test(arg);
             CHECK_ROCBLAS_ERROR(rocblas_trmm_batched_fn(handle,
@@ -391,16 +616,17 @@ void testing_trmm_batched(const Arguments& arg)
                                                         lda,
                                                         dB.ptr_on_device(),
                                                         ldb,
+                                                        (*dOut).ptr_on_device(),
+                                                        ldOut,
                                                         batch_count));
             handle.post_test(arg);
-            CHECK_HIP_ERROR(hB.transfer_from(dB));
+            CHECK_HIP_ERROR(hC.transfer_from(*dOut));
         }
 
         if(arg.pointer_mode_device)
         {
-            // calculate dB <- A^(-1) B   rocblas_device_pointer_device
             CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_device));
-            CHECK_HIP_ERROR(dB.transfer_from(hB_gold));
+            CHECK_HIP_ERROR((*dOut).transfer_from(hC_gold));
             CHECK_HIP_ERROR(d_alpha.transfer_from(h_alpha));
 
             CHECK_ROCBLAS_ERROR(rocblas_trmm_batched_fn(handle,
@@ -415,17 +641,22 @@ void testing_trmm_batched(const Arguments& arg)
                                                         lda,
                                                         dB.ptr_on_device(),
                                                         ldb,
+                                                        (*dOut).ptr_on_device(),
+                                                        ldOut,
                                                         batch_count));
         }
 
         // CPU BLAS
         cpu_time_used = get_time_us_no_sync();
-        for(rocblas_int b = 0; b < batch_count; b++)
+        for(rocblas_int i = 0; i < batch_count; i++)
         {
-            cblas_trmm<T>(side, uplo, transA, diag, M, N, alpha, hA[b], lda, hB_gold[b], ldb);
+            cblas_trmm<T>(side, uplo, transA, diag, M, N, alpha, hA[i], lda, hB[i], ldb);
         }
         cpu_time_used = get_time_us_no_sync() - cpu_time_used;
 
+        // copy B matrix into C matrix
+        copy_matrix_with_different_leading_dimensions(hB, hC_gold);
+
         if(arg.pointer_mode_host)
         {
             if(arg.unit_check)
@@ -435,23 +666,22 @@ void testing_trmm_batched(const Arguments& arg)
                     // For large K, rocblas_half tends to diverge proportional to K
                     // Tolerance is slightly greater than 1 / 1024.0
                     const double tol = K * sum_error_tolerance<T>;
-                    near_check_general<T>(M, N, ldb, hB_gold, hB, batch_count, tol);
+                    near_check_general<T>(M, N, ldc, hC_gold, hC, batch_count, tol);
                 }
                 else
                 {
-                    unit_check_general<T>(M, N, ldb, hB_gold, hB, batch_count);
+                    unit_check_general<T>(M, N, ldc, hC_gold, hC, batch_count);
                 }
             }
             if(arg.norm_check)
             {
                 err_host
-                    = std::abs(norm_check_general<T>('F', M, N, ldb, hB_gold, hB, batch_count));
+                    = std::abs(norm_check_general<T>('F', M, N, ldc, hC_gold, hC, batch_count));
             }
         }
         if(arg.pointer_mode_device)
         {
-            // fetch GPU
-            CHECK_HIP_ERROR(hB.transfer_from(dB));
+            CHECK_HIP_ERROR(hC.transfer_from(*dOut));
 
             if(arg.unit_check)
             {
@@ -460,18 +690,17 @@ void testing_trmm_batched(const Arguments& arg)
                     // For large K, rocblas_half tends to diverge proportional to K
                     // Tolerance is slightly greater than 1 / 1024.0
                     const double tol = K * sum_error_tolerance<T>;
-                    near_check_general<T>(M, N, ldb, hB_gold, hB, batch_count, tol);
+                    near_check_general<T>(M, N, ldc, hC_gold, hC, batch_count, tol);
                 }
                 else
                 {
-                    unit_check_general<T>(M, N, ldb, hB_gold, hB, batch_count);
+                    unit_check_general<T>(M, N, ldc, hC_gold, hC, batch_count);
                 }
             }
-
             if(arg.norm_check)
             {
                 err_device
-                    = std::abs(norm_check_general<T>('F', M, N, ldb, hB_gold, hB, batch_count));
+                    = std::abs(norm_check_general<T>('F', M, N, ldc, hC_gold, hC, batch_count));
             }
         }
     }
@@ -497,6 +726,8 @@ void testing_trmm_batched(const Arguments& arg)
                                                         lda,
                                                         dB.ptr_on_device(),
                                                         ldb,
+                                                        (*dOut).ptr_on_device(),
+                                                        ldOut,
                                                         batch_count));
         }
 
@@ -517,6 +748,8 @@ void testing_trmm_batched(const Arguments& arg)
                                     lda,
                                     dB.ptr_on_device(),
                                     ldb,
+                                    (*dOut).ptr_on_device(),
+                                    ldOut,
                                     batch_count);
         }
         gpu_time_used = get_time_us_sync(stream) - gpu_time_used;
@@ -530,6 +763,7 @@ void testing_trmm_batched(const Arguments& arg)
                       e_alpha,
                       e_lda,
                       e_ldb,
+                      e_ldc,
                       e_batch_count>{}
             .log_args<T>(rocblas_cout,
                          arg,
@@ -540,5 +774,4 @@ void testing_trmm_batched(const Arguments& arg)
                          err_host,
                          err_device);
     }
-#endif // ROCBLAS_V3
 }
