@@ -198,7 +198,6 @@ void testing_trtri_batched(const Arguments& arg)
     // Check host memory allocation
     CHECK_HIP_ERROR(hA.memcheck());
     CHECK_HIP_ERROR(hB.memcheck());
-    CHECK_HIP_ERROR(hA_2.memcheck());
 
     // Allocate device memory
     device_batch_matrix<T> dA(N, N, lda, batch_count, false, offsetA);
@@ -369,7 +368,6 @@ void testing_trtri_batched(const Arguments& arg)
 
         // copy output from device to CPU
         CHECK_HIP_ERROR(hA.transfer_from(dinvA));
-        CHECK_HIP_ERROR(hA_2.transfer_from(dA));
 
         /* =====================================================================
            CPU BLAS
@@ -384,20 +382,22 @@ void testing_trtri_batched(const Arguments& arg)
         if(arg.timing)
             cpu_time_used = get_time_us_no_sync() - cpu_time_used;
 
+        // test out-of-place
+        const double rel_error = trtri_tolerance<T>(N);
         if(arg.unit_check)
-        {
-            const double rel_error = trtri_tolerance<T>(N);
             near_check_general<T>(N, N, lda, hB, hA, batch_count, rel_error);
-            near_check_general<T>(N, N, lda, hB, hA_2, batch_count, rel_error);
-        }
 
         if(arg.norm_check)
-        {
             rocblas_error_out
                 = norm_check_symmetric<T>('F', char_uplo, N, lda, hB, hA, batch_count);
-            rocblas_error_in
-                = norm_check_symmetric<T>('F', char_uplo, N, lda, hB, hA_2, batch_count);
-        }
+
+        // test in-place
+        CHECK_HIP_ERROR(hA.transfer_from(dA));
+        if(arg.unit_check)
+            near_check_general<T>(N, N, lda, hB, hA, batch_count, rel_error);
+
+        if(arg.norm_check)
+            rocblas_error_in = norm_check_symmetric<T>('F', char_uplo, N, lda, hB, hA, batch_count);
     }
 
     if(arg.timing)
@@ -409,6 +409,9 @@ void testing_trtri_batched(const Arguments& arg)
         CHECK_ROCBLAS_ERROR(rocblas_get_stream(handle, &stream));
         for(int i = 0; i < total_calls; i++)
         {
+            if(i == number_cold_calls)
+                gpu_time_used = get_time_us_sync(stream);
+
             rocblas_trtri_batched_fn(handle,
                                      uplo,
                                      diag,
@@ -418,9 +421,6 @@ void testing_trtri_batched(const Arguments& arg)
                                      dinvA.ptr_on_device(),
                                      lda,
                                      batch_count);
-
-            if(i == number_cold_calls)
-                gpu_time_used = get_time_us_sync(stream);
         }
 
         gpu_time_used = get_time_us_sync(stream) - gpu_time_used;
