@@ -288,15 +288,6 @@ void testing_gemm_strided_batched_ex(const Arguments& arg)
     // check for invalid sizes
     bool invalid_size = M < 0 || N < 0 || K < 0 || lda < A_row || ldb < B_row || ldc < M || ldd < M
                         || batch_count < 0;
-
-    // size checking is only needed for int8x4
-    bool pack_to_int8x4 = arg.flags & rocblas_gemm_flags_pack_int8x4;
-    bool int8_invalid
-        = (pack_to_int8x4
-           && std::is_same_v<
-               Ti,
-               int8_t> && (K % 4 != 0 || (transA != rocblas_operation_none && lda % 4 != 0) || (transB == rocblas_operation_none && ldb % 4 != 0) || stride_a % 4 != 0 || stride_b % 4 != 0));
-
     if(invalid_size || !M || !N || !batch_count)
     {
         EXPECT_ROCBLAS_STATUS(rocblas_gemm_strided_batched_ex_fn(handle,
@@ -331,51 +322,6 @@ void testing_gemm_strided_batched_ex(const Arguments& arg)
                               invalid_size ? rocblas_status_invalid_size : rocblas_status_success);
         return;
     }
-    if(int8_invalid)
-    {
-        // Allocate host memory
-        device_strided_batch_matrix<Ti> dA(A_row, A_col, lda, stride_a, batch_count);
-        device_strided_batch_matrix<Ti> dB(B_row, B_col, ldb, stride_b, batch_count);
-        device_strided_batch_matrix<To> dC(M, N, ldc, stride_c, batch_count);
-        device_strided_batch_matrix<To> dD(M, N, ldd, stride_d, batch_count);
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dA.memcheck());
-        CHECK_DEVICE_ALLOCATION(dB.memcheck());
-        CHECK_DEVICE_ALLOCATION(dC.memcheck());
-        CHECK_DEVICE_ALLOCATION(dD.memcheck());
-        EXPECT_ROCBLAS_STATUS(rocblas_gemm_strided_batched_ex_fn(handle,
-                                                                 transA,
-                                                                 transB,
-                                                                 M,
-                                                                 N,
-                                                                 K,
-                                                                 &h_alpha_Tc,
-                                                                 dA,
-                                                                 arg.a_type,
-                                                                 lda,
-                                                                 stride_a,
-                                                                 dB,
-                                                                 arg.b_type,
-                                                                 ldb,
-                                                                 stride_b,
-                                                                 &h_beta_Tc,
-                                                                 dC,
-                                                                 arg.c_type,
-                                                                 ldc,
-                                                                 stride_c,
-                                                                 dD,
-                                                                 arg.d_type,
-                                                                 ldd,
-                                                                 stride_d,
-                                                                 batch_count,
-                                                                 arg.compute_type,
-                                                                 algo,
-                                                                 solution_index,
-                                                                 flags),
-                              rocblas_status_invalid_size);
-        return;
-    }
 
 #ifdef ROCBLAS_BENCH
     if(rocblas_internal_tensile_debug_skip_launch())
@@ -417,7 +363,7 @@ void testing_gemm_strided_batched_ex(const Arguments& arg)
     }
 #endif
     // update after invalid checks
-    if(!arg.c_noalias_d)
+    if(!arg.outofplace)
     {
         ldd      = ldc;
         stride_d = stride_c;
@@ -449,9 +395,9 @@ void testing_gemm_strided_batched_ex(const Arguments& arg)
     // if C==D, allocate C big enough for the larger of C and D; D points to C
     device_strided_batch_matrix<To> dC(M, N, ldc, stride_c, batch_count);
     device_strided_batch_matrix<To> dD
-        = (arg.c_noalias_d) ? device_strided_batch_matrix<To>(M, N, ldd, stride_d, batch_count)
-                            : device_strided_batch_matrix<To>(0, 1, 1, 1, 1);
-    device_strided_batch_matrix<To>& dDref = (arg.c_noalias_d) ? dD : dC;
+        = (arg.outofplace) ? device_strided_batch_matrix<To>(M, N, ldd, stride_d, batch_count)
+                           : device_strided_batch_matrix<To>(0, 1, 1, 1, 1);
+    device_strided_batch_matrix<To>& dDref = (arg.outofplace) ? dD : dC;
     device_vector<Tc>                d_alpha_Tc(1);
     device_vector<Tc>                d_beta_Tc(1);
 
@@ -513,36 +459,8 @@ void testing_gemm_strided_batched_ex(const Arguments& arg)
 #endif
 
     // copy data from CPU to device
-    if(std::is_same_v<Ti, int8_t> && transA == rocblas_operation_none && pack_to_int8x4)
-    {
-        host_strided_batch_matrix<Ti> hA_packed(A_row, A_col, lda, stride_a, batch_count);
-        hA_packed.copy_from(hA);
-
-        for(int b = 0; b < batch_count; b++)
-            rocblas_packInt8(hA_packed[b], hA[b], M, K, lda);
-
-        CHECK_HIP_ERROR(dA.transfer_from(hA_packed));
-    }
-    else
-    {
-        CHECK_HIP_ERROR(dA.transfer_from(hA));
-    }
-
-    // if int8 and B transposed and valid case, pack B
-    if(std::is_same_v<Ti, int8_t> && transB != rocblas_operation_none && pack_to_int8x4)
-    {
-        host_strided_batch_matrix<Ti> hB_packed(B_row, B_col, ldb, stride_b, batch_count);
-        hB_packed.copy_from(hB);
-        for(int b = 0; b < batch_count; b++)
-            rocblas_packInt8(hB_packed[b], hB[b], N, K, ldb);
-
-        CHECK_HIP_ERROR(dB.transfer_from(hB_packed));
-    }
-    else
-    {
-        CHECK_HIP_ERROR(dB.transfer_from(hB));
-    }
-
+    CHECK_HIP_ERROR(dA.transfer_from(hA));
+    CHECK_HIP_ERROR(dB.transfer_from(hB));
     CHECK_HIP_ERROR(dC.transfer_from(hC));
 
     if(arg.unit_check || arg.norm_check)
