@@ -489,18 +489,20 @@ void testing_trsm_batched_ex(const Arguments& arg)
 
             if(K % TRSM_BLOCK != 0 || blocks == 0)
             {
-                CHECK_ROCBLAS_ERROR(
-                    rocblas_trtri_strided_batched<T>(handle,
-                                                     uplo,
-                                                     diag,
-                                                     K - TRSM_BLOCK * blocks,
-                                                     dA[b] + stride_A * blocks,
-                                                     lda,
-                                                     stride_A,
-                                                     dinvA[b] + stride_invA * blocks,
-                                                     TRSM_BLOCK,
-                                                     stride_invA,
-                                                     1));
+                int remainder = K - TRSM_BLOCK * blocks;
+                if(remainder)
+                    CHECK_ROCBLAS_ERROR(
+                        rocblas_trtri_strided_batched<T>(handle,
+                                                         uplo,
+                                                         diag,
+                                                         remainder,
+                                                         dA[b] + stride_A * blocks,
+                                                         lda,
+                                                         stride_A,
+                                                         dinvA[b] + stride_invA * blocks,
+                                                         TRSM_BLOCK,
+                                                         stride_invA,
+                                                         1));
             }
         }
 
