@@ -108,6 +108,21 @@ auto rocblas_simple_dispatch(const Arguments& arg)
     }
 }
 
+// general gtest use only for now
+template <template <typename...> class TEST>
+auto rocblas_f8_dispatch(const Arguments& arg)
+{
+    switch(arg.a_type)
+    {
+    case rocblas_datatype_f8_r:
+        return TEST<rocblas_f8>{}(arg);
+    case rocblas_datatype_bf8_r:
+        return TEST<rocblas_bf8>{}(arg);
+    default:
+        return TEST<void>{}(arg);
+    }
+}
+
 // BLAS1 functions
 template <template <typename...> class TEST>
 auto rocblas_blas1_dispatch(const Arguments& arg)
@@ -373,6 +388,41 @@ auto rocblas_blas1_ex_dispatch(const Arguments& arg)
     return TEST<void>{}(arg);
 }
 
+// gemv_batched and gev_strided_batched functions
+template <template <typename...> class TEST>
+auto rocblas_gemv_batched_and_strided_batched_dispatch(const Arguments& arg)
+{
+    const auto Ti = arg.a_type, To = arg.c_type, Tex = arg.compute_type;
+
+    // covers HSH, HSS, TST, TSS precisions for gemv_batched and gev_strided_batched
+    if(Ti != Tex && (Ti == rocblas_datatype_f16_r || Ti == rocblas_datatype_bf16_r)
+       && (To == Ti || To == rocblas_datatype_f32_r))
+    {
+        if(Ti == rocblas_datatype_f16_r && Tex == rocblas_datatype_f32_r && To == Ti)
+        {
+            return TEST<rocblas_half, float, rocblas_half>{}(arg);
+        }
+        else if(Ti == rocblas_datatype_f16_r && Tex == rocblas_datatype_f32_r && To == Tex)
+        {
+            return TEST<rocblas_half, float, float>{}(arg);
+        }
+        else if(Ti == rocblas_datatype_bf16_r && Tex == rocblas_datatype_f32_r && To == Ti)
+        {
+            return TEST<rocblas_bfloat16, float, rocblas_bfloat16>{}(arg);
+        }
+        else if(Ti == rocblas_datatype_bf16_r && Tex == rocblas_datatype_f32_r && To == Tex)
+        {
+            return TEST<rocblas_bfloat16, float, float>{}(arg);
+        }
+    }
+    // covers s, d, c, z precisions for gemv_batched and gev_strided_batched
+    else
+    {
+        return rocblas_simple_dispatch<TEST>(arg); // Ti = Tex = To
+    }
+    return TEST<void, void, void>{}(arg);
+}
+
 // gemm functions
 template <template <typename...> class TEST>
 auto rocblas_gemm_dispatch(const Arguments& arg)
@@ -391,11 +441,8 @@ auto rocblas_gemm_dispatch(const Arguments& arg)
 
     if(arg.b_type == Ti && arg.d_type == To)
     {
-        if(Ti != To) // covers HPA: HSS, BSS, I8II, 4xi8II
+        if(Ti != To) // covers HPA: HSS, BSS, I8II
         {
-            // TODO- Maybe we could add a new datatype_enum such as rocblas_datatype_i8x4_r
-            // So that we could go to the correct branch here.
-            // So far, using whether int8_t or int8x4 is determined in TEST function (gemm_ex)
             if(Ti == rocblas_datatype_i8_r && To == rocblas_datatype_i32_r && Tc == To)
             {
                 return TEST<int8_t, int32_t, int32_t>{}(arg);
@@ -410,6 +457,10 @@ auto rocblas_gemm_dispatch(const Arguments& arg)
                     return TEST<rocblas_f8, rocblas_f8, float, float>{}(arg);
                 else if(To == rocblas_datatype_f32_r && Ti == rocblas_datatype_bf8_r)
                     return TEST<rocblas_bf8, rocblas_bf8, float, float>{}(arg);
+                else if(To == rocblas_datatype_f16_r && Ti == rocblas_datatype_f8_r)
+                    return TEST<rocblas_f8, rocblas_f8, rocblas_half, float>{}(arg);
+                else if(To == rocblas_datatype_f16_r && Ti == rocblas_datatype_bf8_r)
+                    return TEST<rocblas_bf8, rocblas_bf8, rocblas_half, float>{}(arg);
             }
             else if(To == rocblas_datatype_f32_r && Tc == rocblas_datatype_f32_r)
             {
@@ -478,6 +529,12 @@ auto rocblas_gemm_dispatch(const Arguments& arg)
         else if(arg.a_type == rocblas_datatype_bf8_r && arg.b_type == rocblas_datatype_f8_r
                 && To == rocblas_datatype_bf8_r)
             return TEST<rocblas_bf8, rocblas_f8, rocblas_bf8, float>{}(arg);
+        else if(arg.a_type == rocblas_datatype_f8_r && arg.b_type == rocblas_datatype_bf8_r
+                && To == rocblas_datatype_f16_r)
+            return TEST<rocblas_f8, rocblas_bf8, rocblas_half, float>{}(arg);
+        else if(arg.a_type == rocblas_datatype_bf8_r && arg.b_type == rocblas_datatype_f8_r
+                && To == rocblas_datatype_f16_r)
+            return TEST<rocblas_bf8, rocblas_f8, rocblas_half, float>{}(arg);
     }
     else if(arg.d_type == To)
     {
