@@ -79,19 +79,11 @@
 #undef hipFree
 #endif
 
-#define LIMITED_RAM_STRING "Warning: Attempting to allocate more host memory than available."
-#define LIMITED_MEMORY_STRING "Warning: Attempting to allocate more gpu memory than available."
-#define TOO_MANY_DEVICES_STRING "Warning: Too many devices requested."
-#define HMM_NOT_SUPPORTED "Warning: HMM not supported."
-
-// TODO: This is dependent on internal gtest behaviour.
-// Comparing against result.message() when a test ended. With SUCCEED() that "Succeeded\n" is
-// added to the beginning of the message automatically by gtest, so this must be compared.
-// For GTEST_SKIP() "Skipped\n" is added at the beginning of the message.
-#define LIMITED_RAM_STRING_GTEST "Skipped\n" LIMITED_RAM_STRING
-#define LIMITED_MEMORY_STRING_GTEST "Skipped\n" LIMITED_MEMORY_STRING
-#define TOO_MANY_DEVICES_STRING_GTEST "Skipped\n" TOO_MANY_DEVICES_STRING
-#define HMM_NOT_SUPPORTED_GTEST "Skipped\n" HMM_NOT_SUPPORTED
+// For GTEST_SKIP() we search for these sub-strings in listener to determine skip category
+#define LIMITED_RAM_STRING "skip: RAM"
+#define LIMITED_VRAM_STRING "skip: VRAM"
+#define TOO_FEW_DEVICES_PRESENT_STRING "skip: device_count"
+#define HMM_NOT_SUPPORTED_STRING "skip: HMM"
 
 #define NOOP (void)0
 
@@ -360,7 +352,7 @@ inline void banded_matrix_setup(bool upper, T& h_A, rocblas_int k)
 template <typename T>
 inline void regular_to_packed(bool upper, const T* A, T* AP, rocblas_int n)
 {
-    int index = 0;
+    size_t index = 0;
     if(upper)
     {
         for(int i = 0; i < n; i++)
@@ -395,9 +387,9 @@ inline void regular_to_packed(bool upper, U& h_A, U& h_AP, rocblas_int n)
 #endif
     for(rocblas_int batch_index = 0; batch_index < h_A.batch_count(); ++batch_index)
     {
-        auto* AP    = h_AP[batch_index];
-        auto* A     = h_A[batch_index];
-        int   index = 0;
+        auto*  AP    = h_AP[batch_index];
+        auto*  A     = h_A[batch_index];
+        size_t index = 0;
         if(upper)
         {
             for(int i = 0; i < n; i++)
@@ -489,7 +481,7 @@ void make_unit_diagonal(rocblas_fill uplo, T& h_A)
         // randomly initalize diagonal to ensure we aren't using it's values for tests.
         for(int i = 0; i < N; i++)
         {
-            rocblas_init_nan(A + i * lda + i, 1, 1, 1);
+            rocblas_init(A + i * lda + i, 1, 1, 1);
         }
     }
 }
