@@ -169,6 +169,8 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions(rocblas_handle    ha
                                                             rocblas_int*      list_array,
                                                             rocblas_int*      list_size);
 
+//! @}
+
 ROCBLAS_DEPRECATED_MSG("rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to "
                        "change in future releases")
 /*! @{
@@ -219,6 +221,8 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_hand
                                                                     rocblas_int*     list_array,
                                                                     rocblas_int*     list_size);
 
+//! @}
+
 ROCBLAS_DEPRECATED_MSG(
     "rocblas_gemm_batched_ex_get_solutions is a beta feature and is subject to change "
     "in future releases")
@@ -349,6 +353,8 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_batched_ex_get_solutions(rocblas_hand
                                                                     rocblas_int*      list_array,
                                                                     rocblas_int*      list_size);
 
+//! @}
+
 ROCBLAS_DEPRECATED_MSG("rocblas_gemm_batched_ex_get_solutions_by_type is a beta feature and is "
                        "subject to change in future releases")
 /*! @{
@@ -400,6 +406,8 @@ ROCBLAS_EXPORT rocblas_status
                                                   rocblas_int*     list_array,
                                                   rocblas_int*     list_size);
 
+//! @}
+
 ROCBLAS_DEPRECATED_MSG(
     "rocblas_gemm_strided_batched_ex_get_solutions is a beta feature and is subject "
     "to change in future releases")
@@ -547,6 +555,8 @@ ROCBLAS_EXPORT rocblas_status
                                                   rocblas_int*      list_array,
                                                   rocblas_int*      list_size);
 
+//! @}
+
 ROCBLAS_DEPRECATED_MSG(
     "rocblas_gemm_ex3 is a beta feature and is subject to change in future releases."
     "Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch ")
@@ -567,23 +577,32 @@ ROCBLAS_DEPRECATED_MSG(
     alpha and beta are scalars, and A, B, C, and D are matrices, with
     op( A ) an m by k matrix, op( B ) a k by n matrix and C and D are m by n matrices.
 
-    gemm_ex3 is a temporary API to support float8 computation
-    Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch
+    gemm_ex3 is a temporary API to support float8 computation. Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch.
 
-    Supported types are as follows:
-    | A type | B type | C type | D type | Accumulator type |
+    Supported compute-types are as follows:
+
+        rocblas_compute_type_f32         = 300 or
+        rocblas_compute_type_f8_f8_f32   = 301 or (internalAType_internalBType_AccumulatorType)
+        rocblas_compute_type_f8_bf8_f32  = 302 or
+        rocblas_compute_type_bf8_f8_f32  = 303 or
+        rocblas_compute_type_bf8_bf8_f32 = 304
+
+    Supported types are as follows:  alpha/beta always float
+    | A type | B type | C type | D type | Compute type
     |:-:|:-:|:-:|:-:|:-:|
-    | fp32 | fp32 | fp32 | fp32 | fp32 |
-    | fp16 | fp16 | fp16 | fp16 | fp32 |
-    | bf16 | bf16 | bf16 | bf16 | fp32 |
-    | fp8 or bf8 | fp8 or bf8 | same as D type | fp8 or bf8 | fp32 |
+    | fp8 or bf8 | fp8 or bf8 | fp32 | fp32 | f32
+    | fp8  | fp8 | fp8 | fp8 | f32
+    | fp8 or bf8 | fp8 or bf8 | bf8 | bf8 | f32
+    | fp8 or bf8 | fp8 or bf8 | fp16 | fp16 | f32
+    | fp16 | fp16 | fp16 | fp16 | f8_f8_f32 or f8_bf8_f32 or bf8_f8_f32 or bf8_bf8_f32
+    | fp8 or fp32 | fp8 or fp32 | fp16 | fp16 | f8_f8_f32
+    | fp32 | bfp8 | bfp8 or fp32 | bfp8 or fp32 | f8_bf8_f32
+    | bfp8 | fp32 | fp32 | fp32 | bf8_f8_f32
 
-    Computetypes are as follows:
-    rocblas_compute_type_f32         = 300,
-    rocblas_compute_type_f8_f8_f32   = 301, <--- internalAType_internalBType_AccumulatorType
-    rocblas_compute_type_f8_bf8_f32  = 302,
-    rocblas_compute_type_bf8_f8_f32  = 303,
-    rocblas_compute_type_bf8_bf8_f32 = 304,
+    Note: When using rocBLAS numerical checking with the flag ROCBLAS_CHECK_NUMERICS,
+    gemm_ex3 will check the input data after the quantization stage. Consequently,
+    when rocblas_compute_type_f32 is not used, only the post processed input will be checked. Numerical checking
+    will always take place on f8/bf8 data.
 
     @param[in]
     handle    [rocblas_handle]
@@ -686,6 +705,344 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex3(rocblas_handle      handle,
                                                rocblas_gemm_algo   algo,
                                                int32_t             solution_index,
                                                uint32_t            flags);
+//! @}
+
+/*! @{
+    \brief <b> BLAS EX API </b>
+
+    \details
+    gemm_strided_batched_ex3 performs one of the strided_batched matrix-matrix operations:
+
+        D_i = alpha*op(A_i)*op(B_i) + beta*C_i, for i = 1, ..., batch_count
+
+    where op( X ) is one of
+
+        op( X ) = X      or
+        op( X ) = X**T   or
+        op( X ) = X**H,
+
+    alpha and beta are scalars, and A, B, C, and D are strided_batched matrices, with
+    op( A ) an m by k by batch_count strided_batched matrix,
+    op( B ) a k by n by batch_count strided_batched matrix and
+    C and D are m by n by batch_count strided_batched matrices.
+    C and D may point to the same matrices if their parameters are identical.
+
+    The strided_batched matrices are multiple matrices separated by a constant stride.
+    The number of matrices is batch_count.
+
+    gemm_ex3 is a temporary API to support float8 computation. Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch.
+
+    Supported compute-types are as follows:
+
+        rocblas_compute_type_f32         = 300 or
+        rocblas_compute_type_f8_f8_f32   = 301 or (internalAType_internalBType_AccumulatorType)
+        rocblas_compute_type_f8_bf8_f32  = 302 or
+        rocblas_compute_type_bf8_f8_f32  = 303 or
+        rocblas_compute_type_bf8_bf8_f32 = 304
+
+    Supported types are as follows:  alpha/beta always float
+    | A type | B type | C type | D type | Compute type
+    |:-:|:-:|:-:|:-:|:-:|
+    | fp8 or bf8 | fp8 or bf8 | fp32 | fp32 | f32
+    | fp8  | fp8 | fp8 | fp8 | f32
+    | fp8 or bf8 | fp8 or bf8 | bf8 | bf8 | f32
+    | fp8 or bf8 | fp8 or bf8 | fp16 | fp16 | f32
+    | fp16 | fp16 | fp16 | fp16 | f8_f8_f32 or f8_bf8_f32 or bf8_f8_f32 or bf8_bf8_f32
+    | fp8 or fp32 | fp8 or fp32 | fp16 | fp16 | f8_f8_f32
+    | fp32 | bfp8 | bfp8 or fp32 | bfp8 or fp32 | f8_bf8_f32
+    | bfp8 | fp32 | fp32 | fp32 | bf8_f8_f32
+
+    Note: When using rocBLAS numerical checking with the flag ROCBLAS_CHECK_NUMERICS,
+    gemm_strided_batched_ex3 will check the input data after the quantization stage. Consequently,
+    when rocblas_compute_type_f32 is not used, only the post processed input will be checked. Numerical checking
+    will always take place on f8/bf8 data.
+
+    @param[in]
+    handle    [rocblas_handle]
+              handle to the rocblas library context queue.
+    @param[in]
+    transA    [rocblas_operation]
+              specifies the form of op( A ).
+    @param[in]
+    transB    [rocblas_operation]
+              specifies the form of op( B ).
+    @param[in]
+    m         [rocblas_int]
+              matrix dimension m.
+    @param[in]
+    n         [rocblas_int]
+              matrix dimension n.
+    @param[in]
+    k         [rocblas_int]
+              matrix dimension k.
+    @param[in]
+    alpha     [const void *]
+              device pointer or host pointer specifying the scalar alpha. Same datatype as compute_type.
+    @param[in]
+    a         [void *]
+              device pointer pointing to first matrix A_1.
+    @param[in]
+    a_type    [rocblas_datatype]
+              specifies the datatype of each matrix A_i.
+    @param[in]
+    lda       [rocblas_int]
+              specifies the leading dimension of each A_i.
+    @param[in]
+    stride_a  [rocblas_stride]
+              specifies stride from start of one A_i matrix to the next A_(i + 1).
+    @param[in]
+    b         [void *]
+              device pointer pointing to first matrix B_1.
+    @param[in]
+    b_type    [rocblas_datatype]
+              specifies the datatype of each matrix B_i.
+    @param[in]
+    ldb       [rocblas_int]
+              specifies the leading dimension of each B_i.
+    @param[in]
+    stride_b  [rocblas_stride]
+              specifies stride from start of one B_i matrix to the next B_(i + 1).
+    @param[in]
+    beta      [const void *]
+              device pointer or host pointer specifying the scalar beta. Same datatype as compute_type.
+    @param[in]
+    c         [void *]
+              device pointer pointing to first matrix C_1.
+    @param[in]
+    c_type    [rocblas_datatype]
+              specifies the datatype of each matrix C_i.
+    @param[in]
+    ldc       [rocblas_int]
+              specifies the leading dimension of each C_i.
+    @param[in]
+    stride_c  [rocblas_stride]
+              specifies stride from start of one C_i matrix to the next C_(i + 1).
+    @param[out]
+    d         [void *]
+              device pointer storing each matrix D_i.
+              If d and c pointers are to the same matrix then d_type must equal c_type and ldd must equal ldc
+              and stride_d must equal stride_c or the respective invalid status will be returned.
+    @param[in]
+    d_type    [rocblas_datatype]
+              specifies the datatype of each matrix D_i.
+    @param[in]
+    ldd       [rocblas_int]
+              specifies the leading dimension of each D_i.
+    @param[in]
+    stride_d  [rocblas_stride]
+              specifies stride from start of one D_i matrix to the next D_(i + 1).
+    @param[in]
+    batch_count
+              [rocblas_int]
+              number of gemm operations in the batch.
+    @param[in]
+    compute_type
+              [rocblas_computetype]
+              specifies the datatype of computation.
+    @param[in]
+    algo      [rocblas_gemm_algo]
+              enumerant specifying the algorithm type.
+    @param[in]
+    solution_index
+              [int32_t]
+              if algo is rocblas_gemm_algo_solution_index, this controls which solution is used.
+              When algo is not rocblas_gemm_algo_solution_index, or if solution_index <= 0, the default solution is used.
+              This parameter was unused in previous releases and instead always used the default solution
+    @param[in]
+    flags     [uint32_t]
+              optional gemm flags.
+
+    ********************************************************************/
+ROCBLAS_EXPORT rocblas_status rocblas_gemm_strided_batched_ex3(rocblas_handle      handle,
+                                                               rocblas_operation   transA,
+                                                               rocblas_operation   transB,
+                                                               rocblas_int         m,
+                                                               rocblas_int         n,
+                                                               rocblas_int         k,
+                                                               const void*         alpha,
+                                                               const void*         a,
+                                                               rocblas_datatype    a_type,
+                                                               rocblas_int         lda,
+                                                               rocblas_stride      stride_a,
+                                                               const void*         b,
+                                                               rocblas_datatype    b_type,
+                                                               rocblas_int         ldb,
+                                                               rocblas_stride      stride_b,
+                                                               const void*         beta,
+                                                               const void*         c,
+                                                               rocblas_datatype    c_type,
+                                                               rocblas_int         ldc,
+                                                               rocblas_stride      stride_c,
+                                                               void*               d,
+                                                               rocblas_datatype    d_type,
+                                                               rocblas_int         ldd,
+                                                               rocblas_stride      stride_d,
+                                                               rocblas_int         batch_count,
+                                                               rocblas_computetype compute_type,
+                                                               rocblas_gemm_algo   algo,
+                                                               int32_t             solution_index,
+                                                               uint32_t            flags);
+//! @}
+
+/*! @{
+    \brief <b> BLAS BETA API </b>
+
+    \details
+    gemm_batched_ex3 performs one of the batched matrix-matrix operations:
+
+        D_i = alpha*op(A_i)*op(B_i) + beta*C_i, for i = 1, ..., batch_count.
+
+    where op( X ) is one of
+
+        op( X ) = X      or
+        op( X ) = X**T   or
+        op( X ) = X**H,
+
+    alpha and beta are scalars, and A, B, C, and D are batched pointers to matrices, with
+    op( A ) an m by k by batch_count batched matrix,
+    op( B ) a k by n by batch_count batched matrix and
+    C and D are m by n by batch_count batched matrices.
+    The batched matrices are an array of pointers to matrices.
+    The number of pointers to matrices is batch_count.
+    C and D may point to the same matrices if their parameters are identical.
+
+    gemm_ex3 is a temporary API to support float8 computation. Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch.
+
+    Supported compute-types are as follows:
+
+        rocblas_compute_type_f32         = 300 or
+        rocblas_compute_type_f8_f8_f32   = 301 or (internalAType_internalBType_AccumulatorType)
+        rocblas_compute_type_f8_bf8_f32  = 302 or
+        rocblas_compute_type_bf8_f8_f32  = 303 or
+        rocblas_compute_type_bf8_bf8_f32 = 304
+
+    Supported types are as follows:  alpha/beta always float
+    | A type | B type | C type | D type | Compute type
+    |:-:|:-:|:-:|:-:|:-:|
+    | fp8 or bf8 | fp8 or bf8 | fp32 | fp32 | f32
+    | fp8  | fp8 | fp8 | fp8 | f32
+    | fp8 or bf8 | fp8 or bf8 | bf8 | bf8 | f32
+    | fp8 or bf8 | fp8 or bf8 | fp16 | fp16 | f32
+    | fp16 | fp16 | fp16 | fp16 | f8_f8_f32 or f8_bf8_f32 or bf8_f8_f32 or bf8_bf8_f32
+    | fp8 or fp32 | fp8 or fp32 | fp16 | fp16 | f8_f8_f32
+    | fp32 | bfp8 | bfp8 or fp32 | bfp8 or fp32 | f8_bf8_f32
+    | bfp8 | fp32 | fp32 | fp32 | bf8_f8_f32
+
+    Note: When using rocBLAS numerical checking with the flag ROCBLAS_CHECK_NUMERICS,
+    gemm_batched_ex3 will check the input data after the quantization stage. Consequently,
+    when rocblas_compute_type_f32 is not used, only the post processed input will be checked. Numerical checking
+    will always take place on f8/bf8 data.
+
+    @param[in]
+    handle    [rocblas_handle]
+              handle to the rocblas library context queue.
+    @param[in]
+    transA    [rocblas_operation]
+              specifies the form of op( A ).
+    @param[in]
+    transB    [rocblas_operation]
+              specifies the form of op( B ).
+    @param[in]
+    m         [rocblas_int]
+              matrix dimension m.
+    @param[in]
+    n         [rocblas_int]
+              matrix dimension n.
+    @param[in]
+    k         [rocblas_int]
+              matrix dimension k.
+    @param[in]
+    alpha     [const void *]
+              device pointer or host pointer specifying the scalar alpha. Same datatype as compute_type.
+    @param[in]
+    a         [void *]
+              device pointer storing array of pointers to each matrix A_i.
+    @param[in]
+    a_type    [rocblas_datatype]
+              specifies the datatype of each matrix A_i.
+    @param[in]
+    lda       [rocblas_int]
+              specifies the leading dimension of each A_i.
+    @param[in]
+    b         [void *]
+              device pointer storing array of pointers to each matrix B_i.
+    @param[in]
+    b_type    [rocblas_datatype]
+              specifies the datatype of each matrix B_i.
+    @param[in]
+    ldb       [rocblas_int]
+              specifies the leading dimension of each B_i.
+    @param[in]
+    beta      [const void *]
+              device pointer or host pointer specifying the scalar beta. Same datatype as compute_type.
+    @param[in]
+    c         [void *]
+              device array of device pointers to each matrix C_i.
+    @param[in]
+    c_type    [rocblas_datatype]
+              specifies the datatype of each matrix C_i.
+    @param[in]
+    ldc       [rocblas_int]
+              specifies the leading dimension of each C_i.
+    @param[out]
+    d         [void *]
+              device array of device pointers to each matrix D_i.
+              If d and c are the same array of matrix pointers then d_type must equal c_type and ldd must equal ldc
+              or the respective invalid status will be returned.
+    @param[in]
+    d_type    [rocblas_datatype]
+              specifies the datatype of each matrix D_i.
+    @param[in]
+    ldd       [rocblas_int]
+              specifies the leading dimension of each D_i.
+    @param[in]
+    batch_count
+              [rocblas_int]
+              number of gemm operations in the batch.
+    @param[in]
+    compute_type
+              [rocblas_computetype]
+              specifies the datatype of computation.
+    @param[in]
+    algo      [rocblas_gemm_algo]
+              enumerant specifying the algorithm type.
+    @param[in]
+    solution_index
+              [int32_t]
+              if algo is rocblas_gemm_algo_solution_index, this controls which solution is used.
+              When algo is not rocblas_gemm_algo_solution_index, or if solution_index <= 0, the default solution is used.
+              This parameter was unused in previous releases and instead always used the default solution
+    @param[in]
+    flags     [uint32_t]
+              optional gemm flags.
+
+    ********************************************************************/
+ROCBLAS_EXPORT rocblas_status rocblas_gemm_batched_ex3(rocblas_handle      handle,
+                                                       rocblas_operation   transA,
+                                                       rocblas_operation   transB,
+                                                       rocblas_int         m,
+                                                       rocblas_int         n,
+                                                       rocblas_int         k,
+                                                       const void*         alpha,
+                                                       const void*         a,
+                                                       rocblas_datatype    a_type,
+                                                       rocblas_int         lda,
+                                                       const void*         b,
+                                                       rocblas_datatype    b_type,
+                                                       rocblas_int         ldb,
+                                                       const void*         beta,
+                                                       const void*         c,
+                                                       rocblas_datatype    c_type,
+                                                       rocblas_int         ldc,
+                                                       void*               d,
+                                                       rocblas_datatype    d_type,
+                                                       rocblas_int         ldd,
+                                                       rocblas_int         batch_count,
+                                                       rocblas_computetype compute_type,
+                                                       rocblas_gemm_algo   algo,
+                                                       int32_t             solution_index,
+                                                       uint32_t            flags);
+//! @}
 
 #ifdef __cplusplus
 }
