@@ -24,29 +24,40 @@
 
 namespace
 {
-    template <typename>
+    template <typename, typename>
     constexpr char rocblas_gemv_name[] = "unknown";
     template <>
-    constexpr char rocblas_gemv_name<float>[] = "rocblas_sgemv_batched";
+    constexpr char rocblas_gemv_name<float, float>[] = "rocblas_sgemv_batched";
     template <>
-    constexpr char rocblas_gemv_name<double>[] = "rocblas_dgemv_batched";
+    constexpr char rocblas_gemv_name<double, double>[] = "rocblas_dgemv_batched";
     template <>
-    constexpr char rocblas_gemv_name<rocblas_float_complex>[] = "rocblas_cgemv_batched";
+    constexpr char rocblas_gemv_name<rocblas_float_complex, rocblas_float_complex>[]
+        = "rocblas_cgemv_batched";
     template <>
-    constexpr char rocblas_gemv_name<rocblas_double_complex>[] = "rocblas_zgemv_batched";
+    constexpr char rocblas_gemv_name<rocblas_double_complex, rocblas_double_complex>[]
+        = "rocblas_zgemv_batched";
+    template <>
+    constexpr char rocblas_gemv_name<rocblas_half, rocblas_half>[] = "rocblas_hshgemv_batched";
+    template <>
+    constexpr char rocblas_gemv_name<rocblas_half, float>[] = "rocblas_hssgemv_batched";
+    template <>
+    constexpr char rocblas_gemv_name<rocblas_bfloat16, rocblas_bfloat16>[]
+        = "rocblas_tstgemv_batched";
+    template <>
+    constexpr char rocblas_gemv_name<rocblas_bfloat16, float>[] = "rocblas_tssgemv_batched";
 
-    template <typename T>
+    template <typename Ti, typename Tex = Ti, typename To = Ti>
     rocblas_status rocblas_gemv_batched_impl(rocblas_handle    handle,
                                              rocblas_operation transA,
                                              rocblas_int       m,
                                              rocblas_int       n,
-                                             const T*          alpha,
-                                             const T* const    A[],
+                                             const Tex*        alpha,
+                                             const Ti* const   A[],
                                              rocblas_int       lda,
-                                             const T* const    x[],
+                                             const Ti* const   x[],
                                              rocblas_int       incx,
-                                             const T*          beta,
-                                             T* const          y[],
+                                             const Tex*        beta,
+                                             To* const         y[],
                                              rocblas_int       incy,
                                              rocblas_int       batch_count)
     {
@@ -54,7 +65,7 @@ namespace
             return rocblas_status_invalid_handle;
 
         size_t dev_bytes
-            = rocblas_internal_gemv_kernel_workspace_size<T>(transA, m, n, batch_count);
+            = rocblas_internal_gemv_kernel_workspace_size<Tex>(transA, m, n, batch_count);
         if(handle->is_device_memory_size_query())
             return handle->set_optimal_device_memory_size(dev_bytes);
 
@@ -69,7 +80,7 @@ namespace
 
             if(layer_mode & rocblas_layer_mode_log_trace)
                 log_trace(handle,
-                          rocblas_gemv_name<T>,
+                          rocblas_gemv_name<Ti, To>,
                           transA,
                           m,
                           n,
@@ -84,29 +95,61 @@ namespace
                           batch_count);
 
             if(layer_mode & rocblas_layer_mode_log_bench)
-                log_bench(handle,
-                          "./rocblas-bench -f gemv_batched -r",
-                          rocblas_precision_string<T>,
-                          "--transposeA",
-                          transA_letter,
-                          "-m",
-                          m,
-                          "-n",
-                          n,
-                          LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                          "--lda",
-                          lda,
-                          "--incx",
-                          incx,
-                          LOG_BENCH_SCALAR_VALUE(handle, beta),
-                          "--incy",
-                          incy,
-                          "--batch_count",
-                          batch_count);
+            {
+                if constexpr(std::is_same<Ti, rocblas_half>{}
+                             || std::is_same<Ti, rocblas_bfloat16>{})
+                {
+                    log_bench(handle,
+                              "./rocblas-bench -f gemv_batched --a_type",
+                              rocblas_precision_string<Ti>,
+                              "--c_type",
+                              rocblas_precision_string<To>,
+                              "--compute_type",
+                              rocblas_precision_string<Tex>,
+                              "--transposeA",
+                              transA_letter,
+                              "-m",
+                              m,
+                              "-n",
+                              n,
+                              LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                              "--lda",
+                              lda,
+                              "--incx",
+                              incx,
+                              LOG_BENCH_SCALAR_VALUE(handle, beta),
+                              "--incy",
+                              incy,
+                              "--batch_count",
+                              batch_count);
+                }
+                else
+                {
+                    log_bench(handle,
+                              "./rocblas-bench -f gemv_batched -r",
+                              rocblas_precision_string<Ti>,
+                              "--transposeA",
+                              transA_letter,
+                              "-m",
+                              m,
+                              "-n",
+                              n,
+                              LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                              "--lda",
+                              lda,
+                              "--incx",
+                              incx,
+                              LOG_BENCH_SCALAR_VALUE(handle, beta),
+                              "--incy",
+                              incy,
+                              "--batch_count",
+                              batch_count);
+                }
+            }
 
             if(layer_mode & rocblas_layer_mode_log_profile)
                 log_profile(handle,
-                            rocblas_gemv_name<T>,
+                            rocblas_gemv_name<Ti, To>,
                             "transA",
                             transA_letter,
                             "M",
@@ -123,27 +166,27 @@ namespace
                             batch_count);
         }
 
-        rocblas_status arg_status = rocblas_internal_gemv_arg_check<T>(handle,
-                                                                       transA,
-                                                                       m,
-                                                                       n,
-                                                                       alpha,
-                                                                       0,
-                                                                       A,
-                                                                       0,
-                                                                       lda,
-                                                                       0,
-                                                                       x,
-                                                                       0,
-                                                                       incx,
-                                                                       0,
-                                                                       beta,
-                                                                       0,
-                                                                       y,
-                                                                       0,
-                                                                       incy,
-                                                                       0,
-                                                                       batch_count);
+        rocblas_status arg_status = rocblas_internal_gemv_arg_check(handle,
+                                                                    transA,
+                                                                    m,
+                                                                    n,
+                                                                    alpha,
+                                                                    0,
+                                                                    A,
+                                                                    0,
+                                                                    lda,
+                                                                    0,
+                                                                    x,
+                                                                    0,
+                                                                    incx,
+                                                                    0,
+                                                                    beta,
+                                                                    0,
+                                                                    y,
+                                                                    0,
+                                                                    incy,
+                                                                    0,
+                                                                    batch_count);
         if(arg_status != rocblas_status_continue)
             return arg_status;
 
@@ -156,7 +199,7 @@ namespace
         {
             bool           is_input = true;
             rocblas_status gemv_check_numerics_status
-                = rocblas_gemv_check_numerics(rocblas_gemv_name<T>,
+                = rocblas_gemv_check_numerics(rocblas_gemv_name<Ti, To>,
                                               handle,
                                               transA,
                                               m,
@@ -180,28 +223,28 @@ namespace
                 return gemv_check_numerics_status;
         }
 
-        rocblas_status status = rocblas_internal_gemv_batched_template(handle,
-                                                                       transA,
-                                                                       m,
-                                                                       n,
-                                                                       alpha,
-                                                                       0,
-                                                                       A,
-                                                                       0,
-                                                                       lda,
-                                                                       0,
-                                                                       x,
-                                                                       0,
-                                                                       incx,
-                                                                       0,
-                                                                       beta,
-                                                                       0,
-                                                                       y,
-                                                                       0,
-                                                                       incy,
-                                                                       0,
-                                                                       batch_count,
-                                                                       (T*)w_mem);
+        rocblas_status status = rocblas_internal_gemv_template(handle,
+                                                               transA,
+                                                               m,
+                                                               n,
+                                                               alpha,
+                                                               0,
+                                                               A,
+                                                               0,
+                                                               lda,
+                                                               0,
+                                                               x,
+                                                               0,
+                                                               incx,
+                                                               0,
+                                                               beta,
+                                                               0,
+                                                               y,
+                                                               0,
+                                                               incy,
+                                                               0,
+                                                               batch_count,
+                                                               (Tex*)w_mem);
 
         status = (status != rocblas_status_success) ? status : perf_status;
         if(status != rocblas_status_success)
@@ -211,7 +254,7 @@ namespace
         {
             bool           is_input = false;
             rocblas_status gemv_check_numerics_status
-                = rocblas_gemv_check_numerics(rocblas_gemv_name<T>,
+                = rocblas_gemv_check_numerics(rocblas_gemv_name<Ti, To>,
                                               handle,
                                               transA,
                                               m,
@@ -338,4 +381,96 @@ catch(...)
     return exception_to_rocblas_status();
 }
 
+rocblas_status rocblas_hshgemv_batched(rocblas_handle            handle,
+                                       rocblas_operation         transA,
+                                       rocblas_int               m,
+                                       rocblas_int               n,
+                                       const float*              alpha,
+                                       const rocblas_half* const A[],
+                                       rocblas_int               lda,
+                                       const rocblas_half* const x[],
+                                       rocblas_int               incx,
+                                       const float*              beta,
+                                       rocblas_half* const       y[],
+                                       rocblas_int               incy,
+                                       rocblas_int               batch_count)
+try
+{
+    return rocblas_gemv_batched_impl<rocblas_half, float, rocblas_half>(
+        handle, transA, m, n, alpha, A, lda, x, incx, beta, y, incy, batch_count);
+}
+catch(...)
+{
+    return exception_to_rocblas_status();
+}
+
+rocblas_status rocblas_hssgemv_batched(rocblas_handle            handle,
+                                       rocblas_operation         transA,
+                                       rocblas_int               m,
+                                       rocblas_int               n,
+                                       const float*              alpha,
+                                       const rocblas_half* const A[],
+                                       rocblas_int               lda,
+                                       const rocblas_half* const x[],
+                                       rocblas_int               incx,
+                                       const float*              beta,
+                                       float* const              y[],
+                                       rocblas_int               incy,
+                                       rocblas_int               batch_count)
+try
+{
+    return rocblas_gemv_batched_impl<rocblas_half, float, float>(
+        handle, transA, m, n, alpha, A, lda, x, incx, beta, y, incy, batch_count);
+}
+catch(...)
+{
+    return exception_to_rocblas_status();
+}
+
+rocblas_status rocblas_tstgemv_batched(rocblas_handle                handle,
+                                       rocblas_operation             transA,
+                                       rocblas_int                   m,
+                                       rocblas_int                   n,
+                                       const float*                  alpha,
+                                       const rocblas_bfloat16* const A[],
+                                       rocblas_int                   lda,
+                                       const rocblas_bfloat16* const x[],
+                                       rocblas_int                   incx,
+                                       const float*                  beta,
+                                       rocblas_bfloat16* const       y[],
+                                       rocblas_int                   incy,
+                                       rocblas_int                   batch_count)
+try
+{
+    return rocblas_gemv_batched_impl<rocblas_bfloat16, float, rocblas_bfloat16>(
+        handle, transA, m, n, alpha, A, lda, x, incx, beta, y, incy, batch_count);
+}
+catch(...)
+{
+    return exception_to_rocblas_status();
+}
+
+rocblas_status rocblas_tssgemv_batched(rocblas_handle                handle,
+                                       rocblas_operation             transA,
+                                       rocblas_int                   m,
+                                       rocblas_int                   n,
+                                       const float*                  alpha,
+                                       const rocblas_bfloat16* const A[],
+                                       rocblas_int                   lda,
+                                       const rocblas_bfloat16* const x[],
+                                       rocblas_int                   incx,
+                                       const float*                  beta,
+                                       float* const                  y[],
+                                       rocblas_int                   incy,
+                                       rocblas_int                   batch_count)
+try
+{
+    return rocblas_gemv_batched_impl<rocblas_bfloat16, float, float>(
+        handle, transA, m, n, alpha, A, lda, x, incx, beta, y, incy, batch_count);
+}
+catch(...)
+{
+    return exception_to_rocblas_status();
+}
+
 } // extern "C"
