@@ -144,50 +144,50 @@ rocblas_status rocblas_internal_her2_template(rocblas_handle handle,
 
     if(rocblas_pointer_mode_device == handle->pointer_mode)
     {
-        hipLaunchKernelGGL((rocblas_her2_kernel<HER2_DIM_X>),
-                           her2_grid,
-                           her2_threads,
-                           0,
-                           handle->get_stream(),
-                           uplo == rocblas_fill_upper,
-                           n,
-                           nitems,
-                           alpha,
-                           x,
-                           shift_x,
-                           incx,
-                           stride_x,
-                           y,
-                           shift_y,
-                           incy,
-                           stride_y,
-                           A,
-                           lda,
-                           offset_A,
-                           stride_A);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_her2_kernel<HER2_DIM_X>),
+                              her2_grid,
+                              her2_threads,
+                              0,
+                              handle->get_stream(),
+                              uplo == rocblas_fill_upper,
+                              n,
+                              nitems,
+                              alpha,
+                              x,
+                              shift_x,
+                              incx,
+                              stride_x,
+                              y,
+                              shift_y,
+                              incy,
+                              stride_y,
+                              A,
+                              lda,
+                              offset_A,
+                              stride_A);
     }
     else
-        hipLaunchKernelGGL((rocblas_her2_kernel<HER2_DIM_X>),
-                           her2_grid,
-                           her2_threads,
-                           0,
-                           handle->get_stream(),
-                           uplo == rocblas_fill_upper,
-                           n,
-                           nitems,
-                           *alpha,
-                           x,
-                           shift_x,
-                           incx,
-                           stride_x,
-                           y,
-                           shift_y,
-                           incy,
-                           stride_y,
-                           A,
-                           lda,
-                           offset_A,
-                           stride_A);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_her2_kernel<HER2_DIM_X>),
+                              her2_grid,
+                              her2_threads,
+                              0,
+                              handle->get_stream(),
+                              uplo == rocblas_fill_upper,
+                              n,
+                              nitems,
+                              *alpha,
+                              x,
+                              shift_x,
+                              incx,
+                              stride_x,
+                              y,
+                              shift_y,
+                              incy,
+                              stride_y,
+                              A,
+                              lda,
+                              offset_A,
+                              stride_A);
 
     return rocblas_status_success;
 }
