@@ -119,47 +119,47 @@ rocblas_status rocblas_internal_syr2_template(rocblas_handle handle,
     dim3 syr2_threads(SYR2_DIM_X, SYR2_DIM_Y);
 
     if(rocblas_pointer_mode_device == handle->pointer_mode)
-        hipLaunchKernelGGL((rocblas_syr2_kernel<SYR2_DIM_X, SYR2_DIM_Y>),
-                           syr2_grid,
-                           syr2_threads,
-                           0,
-                           handle->get_stream(),
-                           uplo == rocblas_fill_upper,
-                           n,
-                           alpha,
-                           x,
-                           shift_x,
-                           incx,
-                           stride_x,
-                           y,
-                           shift_y,
-                           incy,
-                           stride_y,
-                           A,
-                           lda,
-                           offset_A,
-                           stride_A);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_syr2_kernel<SYR2_DIM_X, SYR2_DIM_Y>),
+                              syr2_grid,
+                              syr2_threads,
+                              0,
+                              handle->get_stream(),
+                              uplo == rocblas_fill_upper,
+                              n,
+                              alpha,
+                              x,
+                              shift_x,
+                              incx,
+                              stride_x,
+                              y,
+                              shift_y,
+                              incy,
+                              stride_y,
+                              A,
+                              lda,
+                              offset_A,
+                              stride_A);
     else
-        hipLaunchKernelGGL((rocblas_syr2_kernel<SYR2_DIM_X, SYR2_DIM_Y>),
-                           syr2_grid,
-                           syr2_threads,
-                           0,
-                           handle->get_stream(),
-                           uplo == rocblas_fill_upper,
-                           n,
-                           *alpha,
-                           x,
-                           shift_x,
-                           incx,
-                           stride_x,
-                           y,
-                           shift_y,
-                           incy,
-                           stride_y,
-                           A,
-                           lda,
-                           offset_A,
-                           stride_A);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_syr2_kernel<SYR2_DIM_X, SYR2_DIM_Y>),
+                              syr2_grid,
+                              syr2_threads,
+                              0,
+                              handle->get_stream(),
+                              uplo == rocblas_fill_upper,
+                              n,
+                              *alpha,
+                              x,
+                              shift_x,
+                              incx,
+                              stride_x,
+                              y,
+                              shift_y,
+                              incy,
+                              stride_y,
+                              A,
+                              lda,
+                              offset_A,
+                              stride_A);
 
     return rocblas_status_success;
 }
