@@ -154,78 +154,78 @@ ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
         if(uplo == rocblas_fill_upper)
         {
             if(incx == 1)
-                hipLaunchKernelGGL((rocblas_syr_kernel_inc1<true, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel_inc1<true, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
             else
-                hipLaunchKernelGGL((rocblas_syr_kernel<true, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   incx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel<true, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      incx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
         }
         else
         {
             if(incx == 1)
-                hipLaunchKernelGGL((rocblas_syr_kernel_inc1<false, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel_inc1<false, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
             else
-                hipLaunchKernelGGL((rocblas_syr_kernel<false, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   incx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel<false, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      incx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
         }
     }
     else // host pointer mode
@@ -233,78 +233,78 @@ ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
         if(uplo == rocblas_fill_upper)
         {
             if(incx == 1)
-                hipLaunchKernelGGL((rocblas_syr_kernel_inc1<true, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   *alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel_inc1<true, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      *alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
             else
-                hipLaunchKernelGGL((rocblas_syr_kernel<true, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   *alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   incx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel<true, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      *alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      incx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
         }
         else
         {
             if(incx == 1)
-                hipLaunchKernelGGL((rocblas_syr_kernel_inc1<false, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   *alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel_inc1<false, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      *alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
             else
-                hipLaunchKernelGGL((rocblas_syr_kernel<false, SYR_DIM_X, T>),
-                                   syr_grid,
-                                   syr_threads,
-                                   0,
-                                   rocblas_stream,
-                                   n,
-                                   nitems,
-                                   *alpha,
-                                   stride_alpha,
-                                   x,
-                                   shiftx,
-                                   incx,
-                                   stridex,
-                                   A,
-                                   offseta,
-                                   lda,
-                                   strideA);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_syr_kernel<false, SYR_DIM_X, T>),
+                                      syr_grid,
+                                      syr_threads,
+                                      0,
+                                      rocblas_stream,
+                                      n,
+                                      nitems,
+                                      *alpha,
+                                      stride_alpha,
+                                      x,
+                                      shiftx,
+                                      incx,
+                                      stridex,
+                                      A,
+                                      offseta,
+                                      lda,
+                                      strideA);
         }
     }
     return rocblas_status_success;
