@@ -29,36 +29,36 @@
 #ifdef tmpv_calc_upperat
 #error tmpv_calc_upperat is already defined
 #endif
-#define tmpv_calc_upperat(_i, _j) (((_j) * ((_j) + 1)) / 2 + (_i))
+#define tmpv_calc_upperat(_i, _j) ((size_t(_j) * ((_j) + 1)) / 2 + (_i))
 
 #ifdef tmpv_calc_lowerat
 #error tmpv_calc_lowerat is already defined
 #endif
-#define tmpv_calc_lowerat(_i, _j) ((_j)*m + ((_i) - (_j)) - (((_j)-1) * (_j)) / 2)
+#define tmpv_calc_lowerat(_i, _j) (size_t(_j) * n + ((_i) - (_j)) - ((size_t(_j) - 1) * (_j)) / 2)
 
 template <rocblas_int NB, typename T>
 ROCBLAS_KERNEL_ILF void rocblas_tpmvn_kernel_calc(bool        is_upper,
                                                   bool        is_unit_diag,
-                                                  rocblas_int m,
+                                                  rocblas_int n,
                                                   const T*    A,
                                                   const T*    x,
                                                   rocblas_int incx,
                                                   T*          workspace)
 {
-    ptrdiff_t tid = blockIdx.x * blockDim.x + threadIdx.x;
+    int tid = blockIdx.x * blockDim.x + threadIdx.x;
 
-    if(tid < m)
+    if(tid < n)
     {
-        T res = x[tid * incx];
+        T res = x[tid * int64_t(incx)];
         if(is_upper)
         {
             if(!is_unit_diag)
             {
                 res *= A[tmpv_calc_upperat(tid, tid)];
             }
-            for(rocblas_int col = tid + 1; col < m; ++col)
+            for(rocblas_int col = tid + 1; col < n; ++col)
             {
-                res += A[tmpv_calc_upperat(tid, col)] * x[col * incx];
+                res += A[tmpv_calc_upperat(tid, col)] * x[col * int64_t(incx)];
             }
         }
         else
@@ -70,7 +70,7 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvn_kernel_calc(bool        is_upper,
             }
             for(rocblas_int col = 0; col < tid; ++col)
             {
-                res += A[tmpv_calc_lowerat(tid, col)] * x[col * incx];
+                res += A[tmpv_calc_lowerat(tid, col)] * x[col * int64_t(incx)];
             }
         }
 
@@ -81,17 +81,17 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvn_kernel_calc(bool        is_upper,
 template <rocblas_int NB, typename T>
 ROCBLAS_KERNEL_ILF void rocblas_tpmvc_kernel_calc(bool        is_upper,
                                                   bool        is_unit_diag,
-                                                  rocblas_int m,
+                                                  rocblas_int n,
                                                   const T*    A,
                                                   const T*    x,
                                                   rocblas_int incx,
                                                   T*          workspace)
 {
-    ptrdiff_t tid = blockIdx.x * blockDim.x + threadIdx.x;
+    int tid = blockIdx.x * blockDim.x + threadIdx.x;
 
-    if(tid < m)
+    if(tid < n)
     {
-        T res = x[tid * incx];
+        T res = x[tid * int64_t(incx)];
         if(is_upper)
         {
             if(!is_unit_diag)
@@ -100,7 +100,7 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvc_kernel_calc(bool        is_upper,
             }
             for(rocblas_int row = 0; row < tid; ++row)
             {
-                res += conj(A[tmpv_calc_upperat(row, tid)]) * x[row * incx];
+                res += conj(A[tmpv_calc_upperat(row, tid)]) * x[row * int64_t(incx)];
             }
         }
         else
@@ -110,9 +110,9 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvc_kernel_calc(bool        is_upper,
                 //cppcheck-suppress duplicateExpression
                 res *= conj(A[tmpv_calc_lowerat(tid, tid)]);
             }
-            for(rocblas_int row = tid + 1; row < m; ++row)
+            for(rocblas_int row = tid + 1; row < n; ++row)
             {
-                res += conj(A[tmpv_calc_lowerat(row, tid)]) * x[row * incx];
+                res += conj(A[tmpv_calc_lowerat(row, tid)]) * x[row * int64_t(incx)];
             }
         }
         workspace[tid] = res;
@@ -122,21 +122,20 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvc_kernel_calc(bool        is_upper,
 template <rocblas_int NB, typename T>
 ROCBLAS_KERNEL_ILF void rocblas_tpmvt_kernel_calc(bool        is_upper,
                                                   bool        is_unit_diag,
-                                                  rocblas_int m,
+                                                  rocblas_int n,
                                                   const T*    A,
                                                   const T*    x,
                                                   rocblas_int incx,
                                                   T*          workspace)
 {
-    ptrdiff_t tid = blockIdx.x * blockDim.x + threadIdx.x;
+    int tid = blockIdx.x * blockDim.x + threadIdx.x;
 
     T           res;
     rocblas_int row;
 
-    if(tid < m)
+    if(tid < n)
     {
-
-        res = x[tid * incx];
+        res = x[tid * int64_t(incx)];
         if(is_upper)
         {
             if(!is_unit_diag)
@@ -146,7 +145,7 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvt_kernel_calc(bool        is_upper,
 
             for(row = 0; row < tid; ++row)
             {
-                res += A[tmpv_calc_upperat(row, tid)] * x[row * incx];
+                res += A[tmpv_calc_upperat(row, tid)] * x[row * int64_t(incx)];
             }
         }
         else
@@ -157,9 +156,9 @@ ROCBLAS_KERNEL_ILF void rocblas_tpmvt_kernel_calc(bool        is_upper,
                 res *= A[tmpv_calc_lowerat(tid, tid)];
             }
 
-            for(row = tid + 1; row < m; ++row)
+            for(row = tid + 1; row < n; ++row)
             {
-                res += A[tmpv_calc_lowerat(row, tid)] * x[row * incx];
+                res += A[tmpv_calc_lowerat(row, tid)] * x[row * int64_t(incx)];
             }
         }
         workspace[tid] = res;
@@ -170,7 +169,7 @@ template <rocblas_int NB, typename A, typename X, typename W>
 ROCBLAS_KERNEL(NB)
 rocblas_tpmvn_kernel(bool           is_upper,
                      bool           is_unit_diag,
-                     rocblas_int    m,
+                     rocblas_int    n,
                      A              a,
                      rocblas_stride shifta,
                      rocblas_stride stridea,
@@ -184,7 +183,7 @@ rocblas_tpmvn_kernel(bool           is_upper,
     static constexpr ptrdiff_t shiftw = 0;
     rocblas_tpmvn_kernel_calc<NB>(is_upper,
                                   is_unit_diag,
-                                  m,
+                                  n,
                                   load_ptr_batch(a, blockIdx.y, shifta, stridea),
                                   load_ptr_batch(x, blockIdx.y, shiftx, stridex),
                                   incx,
@@ -195,7 +194,7 @@ template <rocblas_int NB, typename A, typename X, typename W>
 ROCBLAS_KERNEL(NB)
 rocblas_tpmvt_kernel(bool           is_upper,
                      bool           is_unit_diag,
-                     rocblas_int    m,
+                     rocblas_int    n,
                      A              a,
                      rocblas_stride shifta,
                      rocblas_stride stridea,
@@ -209,7 +208,7 @@ rocblas_tpmvt_kernel(bool           is_upper,
     static constexpr ptrdiff_t shiftw = 0;
     rocblas_tpmvt_kernel_calc<NB>(is_upper,
                                   is_unit_diag,
-                                  m,
+                                  n,
                                   load_ptr_batch(a, blockIdx.y, shifta, stridea),
                                   load_ptr_batch(x, blockIdx.y, shiftx, stridex),
                                   incx,
@@ -220,7 +219,7 @@ template <rocblas_int NB, typename A, typename X, typename W>
 ROCBLAS_KERNEL(NB)
 rocblas_tpmvc_kernel(bool           is_upper,
                      bool           is_unit_diag,
-                     rocblas_int    m,
+                     rocblas_int    n,
                      A              a,
                      rocblas_stride shifta,
                      rocblas_stride stridea,
@@ -234,7 +233,7 @@ rocblas_tpmvc_kernel(bool           is_upper,
     static constexpr ptrdiff_t shiftw = 0;
     rocblas_tpmvc_kernel_calc<NB>(is_upper,
                                   is_unit_diag,
-                                  m,
+                                  n,
                                   load_ptr_batch(a, blockIdx.y, shifta, stridea),
                                   load_ptr_batch(x, blockIdx.y, shiftx, stridex),
                                   incx,
@@ -249,7 +248,7 @@ rocblas_status rocblas_tpmv_template(rocblas_handle    handle,
                                      rocblas_fill      uplo,
                                      rocblas_operation transa,
                                      rocblas_diagonal  diag,
-                                     rocblas_int       m,
+                                     rocblas_int       n,
                                      A                 a,
                                      rocblas_stride    offseta,
                                      rocblas_stride    stridea,
@@ -264,83 +263,83 @@ rocblas_status rocblas_tpmv_template(rocblas_handle    handle,
     //
     // quick return
     //
-    if(!m || !batch_count)
+    if(!n || !batch_count)
     {
         return rocblas_status_success;
     }
 
     hipStream_t rocblas_stream = handle->get_stream();
 
-    ptrdiff_t shiftx = incx < 0 ? offsetx + ptrdiff_t(incx) * (1 - m) : offsetx;
+    int64_t shiftx = incx < 0 ? offsetx + int64_t(incx) * (1 - n) : offsetx;
 
-    dim3 tpmv_grid((m - 1) / NB + 1, batch_count);
+    dim3 tpmv_grid((n - 1) / NB + 1, batch_count);
     dim3 tpmv_threads(NB);
 
     switch(transa)
     {
     case rocblas_operation_none:
     {
-        hipLaunchKernelGGL(rocblas_tpmvn_kernel<NB>,
-                           tpmv_grid,
-                           tpmv_threads,
-                           0,
-                           rocblas_stream,
-                           uplo == rocblas_fill_upper,
-                           diag == rocblas_diagonal_unit,
-                           m,
-                           a,
-                           offseta,
-                           stridea,
-                           x,
-                           shiftx,
-                           incx,
-                           stridex,
-                           workspace,
-                           stridew);
+        ROCBLAS_LAUNCH_KERNEL(rocblas_tpmvn_kernel<NB>,
+                              tpmv_grid,
+                              tpmv_threads,
+                              0,
+                              rocblas_stream,
+                              uplo == rocblas_fill_upper,
+                              diag == rocblas_diagonal_unit,
+                              n,
+                              a,
+                              offseta,
+                              stridea,
+                              x,
+                              shiftx,
+                              incx,
+                              stridex,
+                              workspace,
+                              stridew);
         break;
     }
 
     case rocblas_operation_transpose:
     {
-        hipLaunchKernelGGL(rocblas_tpmvt_kernel<NB>,
-                           tpmv_grid,
-                           tpmv_threads,
-                           0,
-                           rocblas_stream,
-                           uplo == rocblas_fill_upper,
-                           diag == rocblas_diagonal_unit,
-                           m,
-                           a,
-                           offseta,
-                           stridea,
-                           x,
-                           shiftx,
-                           incx,
-                           stridex,
-                           workspace,
-                           stridew);
+        ROCBLAS_LAUNCH_KERNEL(rocblas_tpmvt_kernel<NB>,
+                              tpmv_grid,
+                              tpmv_threads,
+                              0,
+                              rocblas_stream,
+                              uplo == rocblas_fill_upper,
+                              diag == rocblas_diagonal_unit,
+                              n,
+                              a,
+                              offseta,
+                              stridea,
+                              x,
+                              shiftx,
+                              incx,
+                              stridex,
+                              workspace,
+                              stridew);
         break;
     }
 
     case rocblas_operation_conjugate_transpose:
     {
-        hipLaunchKernelGGL(rocblas_tpmvc_kernel<NB>,
-                           tpmv_grid,
-                           tpmv_threads,
-                           0,
-                           rocblas_stream,
-                           uplo == rocblas_fill_upper,
-                           diag == rocblas_diagonal_unit,
-                           m,
-                           a,
-                           offseta,
-                           stridea,
-                           x,
-                           shiftx,
-                           incx,
-                           stridex,
-                           workspace,
-                           stridew);
+        ROCBLAS_LAUNCH_KERNEL(rocblas_tpmvc_kernel<NB>,
+                              tpmv_grid,
+                              tpmv_threads,
+                              0,
+                              rocblas_stream,
+                              uplo == rocblas_fill_upper,
+                              diag == rocblas_diagonal_unit,
+                              n,
+                              a,
+                              offseta,
+                              stridea,
+                              x,
+                              shiftx,
+                              incx,
+                              stridex,
+                              workspace,
+                              stridew);
 
         break;
     }
@@ -352,8 +351,8 @@ rocblas_status rocblas_tpmv_template(rocblas_handle    handle,
     {
         static constexpr rocblas_int offsetw = 0;
         static constexpr rocblas_int incw    = 1;
-        return rocblas_copy_template<NB>(
-            handle, m, workspace, offsetw, incw, stridew, x, offsetx, incx, stridex, batch_count);
+        return rocblas_internal_copy_template<rocblas_int>(
+            handle, n, workspace, offsetw, incw, stridew, x, offsetx, incx, stridex, batch_count);
     }
 }
 
@@ -361,7 +360,7 @@ rocblas_status rocblas_tpmv_template(rocblas_handle    handle,
 template <typename T, typename U>
 rocblas_status rocblas_tpmv_check_numerics(const char*    function_name,
                                            rocblas_handle handle,
-                                           rocblas_int    m,
+                                           rocblas_int    n,
                                            T              A,
                                            rocblas_stride offset_a,
                                            rocblas_stride stride_a,
@@ -376,7 +375,7 @@ rocblas_status rocblas_tpmv_check_numerics(const char*    function_name,
     rocblas_status check_numerics_status
         = rocblas_internal_check_numerics_vector_template(function_name,
                                                           handle,
-                                                          m,
+                                                          n,
                                                           x,
                                                           offset_x,
                                                           inc_x,
@@ -401,7 +400,7 @@ rocblas_status rocblas_tpmv_check_numerics(const char*    function_name,
 template rocblas_status rocblas_tpmv_check_numerics<T_, U_>               \
                                           (const char*    function_name,  \
                                            rocblas_handle handle,         \
-                                           rocblas_int    m,              \
+                                           rocblas_int    n,              \
                                            T_             A,              \
                                            rocblas_stride    offset_a,       \
                                            rocblas_stride stride_a,       \
@@ -436,7 +435,7 @@ template rocblas_status rocblas_tpmv_template                \
                              rocblas_fill      uplo,         \
                              rocblas_operation transa,       \
                              rocblas_diagonal  diag,         \
-                             rocblas_int       m,            \
+                             rocblas_int       n,            \
                              A_                a,            \
                              rocblas_stride    offseta,      \
                              rocblas_stride    stridea,      \
