@@ -356,17 +356,17 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
         dim3 geam_grid(blocksX, blocksY, batch_count);
         dim3 geam_threads(GEAM_DIM_X, GEAM_DIM_Y);
 
-        hipLaunchKernelGGL((rocblas_geam_zero_matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                           geam_grid,
-                           geam_threads,
-                           0,
-                           rocblas_stream,
-                           m,
-                           n,
-                           C,
-                           offset_c,
-                           ldc,
-                           stride_c);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_geam_zero_matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                              geam_grid,
+                              geam_threads,
+                              0,
+                              rocblas_stream,
+                              m,
+                              n,
+                              C,
+                              offset_c,
+                              ldc,
+                              stride_c);
     }
     else if(C == A)
     {
@@ -382,45 +382,45 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
 
         if(pointer_mode == rocblas_pointer_mode_host)
         {
-            hipLaunchKernelGGL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transB,
-                               m,
-                               n,
-                               *alpha,
-                               *beta,
-                               B,
-                               offset_b,
-                               ldb,
-                               stride_b,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transB,
+                                  m,
+                                  n,
+                                  *alpha,
+                                  *beta,
+                                  B,
+                                  offset_b,
+                                  ldb,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transB,
-                               m,
-                               n,
-                               alpha,
-                               beta,
-                               B,
-                               offset_b,
-                               ldb,
-                               stride_b,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transB,
+                                  m,
+                                  n,
+                                  alpha,
+                                  beta,
+                                  B,
+                                  offset_b,
+                                  ldb,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
     }
     else if(C == B)
@@ -437,45 +437,45 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
 
         if(pointer_mode == rocblas_pointer_mode_host)
         {
-            hipLaunchKernelGGL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transA,
-                               m,
-                               n,
-                               *beta,
-                               *alpha,
-                               A,
-                               offset_a,
-                               lda,
-                               stride_a,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transA,
+                                  m,
+                                  n,
+                                  *beta,
+                                  *alpha,
+                                  A,
+                                  offset_a,
+                                  lda,
+                                  stride_a,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transA,
-                               m,
-                               n,
-                               beta,
-                               alpha,
-                               A,
-                               offset_a,
-                               lda,
-                               stride_a,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_inplace_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transA,
+                                  m,
+                                  n,
+                                  beta,
+                                  alpha,
+                                  A,
+                                  offset_a,
+                                  lda,
+                                  stride_a,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
     }
     else if(pointer_mode == rocblas_pointer_mode_host && !*beta)
@@ -492,19 +492,19 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
             dim3 geam_grid(blocks, batch_count);
             dim3 geam_threads(GEAM_DIM);
 
-            hipLaunchKernelGGL((rocblas_geam_1D_2matrix_device<GEAM_DIM>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               size,
-                               *alpha,
-                               A,
-                               offset_a,
-                               stride_a,
-                               C,
-                               offset_c,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_1D_2matrix_device<GEAM_DIM>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  size,
+                                  *alpha,
+                                  A,
+                                  offset_a,
+                                  stride_a,
+                                  C,
+                                  offset_c,
+                                  stride_c);
         }
         else
         {
@@ -518,23 +518,23 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
             dim3 geam_grid(blocksX, blocksY, batch_count);
             dim3 geam_threads(GEAM_DIM_X, GEAM_DIM_Y);
 
-            hipLaunchKernelGGL((rocblas_geam_2matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transA,
-                               m,
-                               n,
-                               *alpha,
-                               A,
-                               offset_a,
-                               lda,
-                               stride_a,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_2matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transA,
+                                  m,
+                                  n,
+                                  *alpha,
+                                  A,
+                                  offset_a,
+                                  lda,
+                                  stride_a,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
     }
     else if(rocblas_pointer_mode_host == pointer_mode && !*alpha)
@@ -551,19 +551,19 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
             dim3 geam_grid(blocks, batch_count);
             dim3 geam_threads(GEAM_DIM);
 
-            hipLaunchKernelGGL((rocblas_geam_1D_2matrix_device<GEAM_DIM>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               size,
-                               *beta,
-                               B,
-                               offset_b,
-                               stride_b,
-                               C,
-                               offset_c,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_1D_2matrix_device<GEAM_DIM>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  size,
+                                  *beta,
+                                  B,
+                                  offset_b,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  stride_c);
         }
         else
         {
@@ -578,23 +578,23 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
             dim3 geam_grid(blocksX, blocksY, batch_count);
             dim3 geam_threads(GEAM_DIM_X, GEAM_DIM_Y);
 
-            hipLaunchKernelGGL((rocblas_geam_2matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transB,
-                               m,
-                               n,
-                               *beta,
-                               B,
-                               offset_b,
-                               ldb,
-                               stride_b,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_2matrix_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transB,
+                                  m,
+                                  n,
+                                  *beta,
+                                  B,
+                                  offset_b,
+                                  ldb,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
     }
     else if(m == lda && transA == rocblas_operation_none && m == ldb
@@ -612,43 +612,43 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
 
         if(rocblas_pointer_mode_host == pointer_mode)
         {
-            hipLaunchKernelGGL((rocblas_geam_1D_device<GEAM_DIM>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               size,
-                               *alpha,
-                               A,
-                               offset_a,
-                               stride_a,
-                               *beta,
-                               B,
-                               offset_b,
-                               stride_b,
-                               C,
-                               offset_c,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_1D_device<GEAM_DIM>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  size,
+                                  *alpha,
+                                  A,
+                                  offset_a,
+                                  stride_a,
+                                  *beta,
+                                  B,
+                                  offset_b,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  stride_c);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_geam_1D_device<GEAM_DIM>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               size,
-                               alpha,
-                               A,
-                               offset_a,
-                               stride_a,
-                               beta,
-                               B,
-                               offset_b,
-                               stride_b,
-                               C,
-                               offset_c,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_1D_device<GEAM_DIM>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  size,
+                                  alpha,
+                                  A,
+                                  offset_a,
+                                  stride_a,
+                                  beta,
+                                  B,
+                                  offset_b,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  stride_c);
         }
     }
     else
@@ -665,55 +665,55 @@ rocblas_status rocblas_geam_template(rocblas_handle    handle,
 
         if(pointer_mode == rocblas_pointer_mode_host)
         {
-            hipLaunchKernelGGL((rocblas_geam_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transA,
-                               transB,
-                               m,
-                               n,
-                               *alpha,
-                               A,
-                               offset_a,
-                               lda,
-                               stride_a,
-                               *beta,
-                               B,
-                               offset_b,
-                               ldb,
-                               stride_b,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transA,
+                                  transB,
+                                  m,
+                                  n,
+                                  *alpha,
+                                  A,
+                                  offset_a,
+                                  lda,
+                                  stride_a,
+                                  *beta,
+                                  B,
+                                  offset_b,
+                                  ldb,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_geam_device<GEAM_DIM_X, GEAM_DIM_Y>),
-                               geam_grid,
-                               geam_threads,
-                               0,
-                               rocblas_stream,
-                               transA,
-                               transB,
-                               m,
-                               n,
-                               alpha,
-                               A,
-                               offset_a,
-                               lda,
-                               stride_a,
-                               beta,
-                               B,
-                               offset_b,
-                               ldb,
-                               stride_b,
-                               C,
-                               offset_c,
-                               ldc,
-                               stride_c);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_geam_device<GEAM_DIM_X, GEAM_DIM_Y>),
+                                  geam_grid,
+                                  geam_threads,
+                                  0,
+                                  rocblas_stream,
+                                  transA,
+                                  transB,
+                                  m,
+                                  n,
+                                  alpha,
+                                  A,
+                                  offset_a,
+                                  lda,
+                                  stride_a,
+                                  beta,
+                                  B,
+                                  offset_b,
+                                  ldb,
+                                  stride_b,
+                                  C,
+                                  offset_c,
+                                  ldc,
+                                  stride_c);
         }
     }
 
