@@ -295,66 +295,66 @@ rocblas_status rocblas_symm_dispatch(rocblas_handle handle,
     if(handle->pointer_mode == rocblas_pointer_mode_device)
     {
         // first scale C so we can use directly for output without work buffer
-        hipLaunchKernelGGL((rocblas_symm_scale_kernel<symm_SCALE_DIM_X, symm_SCALE_DIM_Y>),
-                           symm_scale_grid,
-                           symm_scale_threads,
-                           0,
-                           handle->get_stream(),
-                           m,
-                           n,
-                           beta,
-                           CP,
-                           offsetC,
-                           ldc,
-                           strideC);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_symm_scale_kernel<symm_SCALE_DIM_X, symm_SCALE_DIM_Y>),
+                              symm_scale_grid,
+                              symm_scale_threads,
+                              0,
+                              handle->get_stream(),
+                              m,
+                              n,
+                              beta,
+                              CP,
+                              offsetC,
+                              ldc,
+                              strideC);
 
         if(side == rocblas_side_left)
         {
-            hipLaunchKernelGGL((rocblas_symm_hemm_kernel<HERM, false, symm_DIM_XY>),
-                               symm_grid,
-                               symm_threads,
-                               0,
-                               handle->get_stream(),
-                               uplo == rocblas_fill_upper,
-                               m,
-                               n,
-                               alpha,
-                               AP,
-                               offsetA,
-                               lda,
-                               strideA,
-                               BP,
-                               offsetB,
-                               ldb,
-                               strideB,
-                               CP,
-                               offsetC,
-                               ldc,
-                               strideC);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_symm_hemm_kernel<HERM, false, symm_DIM_XY>),
+                                  symm_grid,
+                                  symm_threads,
+                                  0,
+                                  handle->get_stream(),
+                                  uplo == rocblas_fill_upper,
+                                  m,
+                                  n,
+                                  alpha,
+                                  AP,
+                                  offsetA,
+                                  lda,
+                                  strideA,
+                                  BP,
+                                  offsetB,
+                                  ldb,
+                                  strideB,
+                                  CP,
+                                  offsetC,
+                                  ldc,
+                                  strideC);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_symm_hemm_kernel<HERM, true, symm_DIM_XY>),
-                               symm_grid,
-                               symm_threads,
-                               0,
-                               handle->get_stream(),
-                               uplo == rocblas_fill_upper,
-                               m,
-                               n,
-                               alpha,
-                               AP,
-                               offsetA,
-                               lda,
-                               strideA,
-                               BP,
-                               offsetB,
-                               ldb,
-                               strideB,
-                               CP,
-                               offsetC,
-                               ldc,
-                               strideC);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_symm_hemm_kernel<HERM, true, symm_DIM_XY>),
+                                  symm_grid,
+                                  symm_threads,
+                                  0,
+                                  handle->get_stream(),
+                                  uplo == rocblas_fill_upper,
+                                  m,
+                                  n,
+                                  alpha,
+                                  AP,
+                                  offsetA,
+                                  lda,
+                                  strideA,
+                                  BP,
+                                  offsetB,
+                                  ldb,
+                                  strideB,
+                                  CP,
+                                  offsetC,
+                                  ldc,
+                                  strideC);
         }
     }
     else
@@ -363,66 +363,66 @@ rocblas_status rocblas_symm_dispatch(rocblas_handle handle,
             return rocblas_status_success;
 
         // first scale C so we can use directly for output without work buffer
-        hipLaunchKernelGGL((rocblas_symm_scale_kernel<symm_SCALE_DIM_X, symm_SCALE_DIM_Y>),
-                           symm_scale_grid,
-                           symm_scale_threads,
-                           0,
-                           handle->get_stream(),
-                           m,
-                           n,
-                           *beta,
-                           CP,
-                           offsetC,
-                           ldc,
-                           strideC);
+        ROCBLAS_LAUNCH_KERNEL((rocblas_symm_scale_kernel<symm_SCALE_DIM_X, symm_SCALE_DIM_Y>),
+                              symm_scale_grid,
+                              symm_scale_threads,
+                              0,
+                              handle->get_stream(),
+                              m,
+                              n,
+                              *beta,
+                              CP,
+                              offsetC,
+                              ldc,
+                              strideC);
 
         if(side == rocblas_side_left)
         {
-            hipLaunchKernelGGL((rocblas_symm_hemm_kernel<HERM, false, symm_DIM_XY>),
-                               symm_grid,
-                               symm_threads,
-                               0,
-                               handle->get_stream(),
-                               uplo == rocblas_fill_upper,
-                               m,
-                               n,
-                               *alpha,
-                               AP,
-                               offsetA,
-                               lda,
-                               strideA,
-                               BP,
-                               offsetB,
-                               ldb,
-                               strideB,
-                               CP,
-                               offsetC,
-                               ldc,
-                               strideC);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_symm_hemm_kernel<HERM, false, symm_DIM_XY>),
+                                  symm_grid,
+                                  symm_threads,
+                                  0,
+                                  handle->get_stream(),
+                                  uplo == rocblas_fill_upper,
+                                  m,
+                                  n,
+                                  *alpha,
+                                  AP,
+                                  offsetA,
+                                  lda,
+                                  strideA,
+                                  BP,
+                                  offsetB,
+                                  ldb,
+                                  strideB,
+                                  CP,
+                                  offsetC,
+                                  ldc,
+                                  strideC);
         }
         else
         {
-            hipLaunchKernelGGL((rocblas_symm_hemm_kernel<HERM, true, symm_DIM_XY>),
-                               symm_grid,
-                               symm_threads,
-                               0,
-                               handle->get_stream(),
-                               uplo == rocblas_fill_upper,
-                               m,
-                               n,
-                               *alpha,
-                               AP,
-                               offsetA,
-                               lda,
-                               strideA,
-                               BP,
-                               offsetB,
-                               ldb,
-                               strideB,
-                               CP,
-                               offsetC,
-                               ldc,
-                               strideC);
+            ROCBLAS_LAUNCH_KERNEL((rocblas_symm_hemm_kernel<HERM, true, symm_DIM_XY>),
+                                  symm_grid,
+                                  symm_threads,
+                                  0,
+                                  handle->get_stream(),
+                                  uplo == rocblas_fill_upper,
+                                  m,
+                                  n,
+                                  *alpha,
+                                  AP,
+                                  offsetA,
+                                  lda,
+                                  strideA,
+                                  BP,
+                                  offsetB,
+                                  ldb,
+                                  strideB,
+                                  CP,
+                                  offsetC,
+                                  ldc,
+                                  strideC);
         }
     }
     return rocblas_status_success;
