@@ -22,7 +22,7 @@
 
 #pragma once
 
-#include "macros.hpp"
+#include "definitions.hpp"
 #include "rocblas.h"
 #include "rocblas_ostream.hpp"
 #include "utility.hpp"
@@ -70,6 +70,31 @@ enum class rocblas_device_memory_ownership
     user_owned,
 };
 
+enum class Processor : int
+{
+    // matching enum used in hipGcnArch
+    // only including supported types
+    gfx803  = 803,
+    gfx900  = 900,
+    gfx906  = 906,
+    gfx908  = 908,
+    gfx90a  = 910,
+    gfx940  = 940,
+    gfx941  = 941,
+    gfx942  = 942,
+    gfx1010 = 1010,
+    gfx1011 = 1011,
+    gfx1012 = 1012,
+    gfx1030 = 1030,
+    gfx1031 = 1031,
+    gfx1032 = 1032,
+    gfx1034 = 1034,
+    gfx1035 = 1035,
+    gfx1100 = 1100,
+    gfx1101 = 1101,
+    gfx1102 = 1102
+};
+
 // helper function in handle.cpp
 static rocblas_status free_existing_device_memory(rocblas_handle);
 
@@ -203,6 +228,11 @@ public:
         return archMajor;
     }
 
+    int getArchMajorMinor()
+    {
+        return archMajorMinor;
+    }
+
     // hipEvent_t pointers (for internal use only)
     hipEvent_t startEvent = nullptr;
     hipEvent_t stopEvent  = nullptr;
@@ -224,8 +254,6 @@ public:
 
     // default math_mode is default_math
     rocblas_math_mode math_mode = rocblas_default_math;
-    // used by hipBLAS to set int8 datatype to int8_t or rocblas_int8x4
-    rocblas_int8_type_for_hipblas rocblas_int8_type = rocblas_int8_type_for_hipblas_default;
 
     // logging streams
     std::unique_ptr<rocblas_internal_ostream> log_trace_os;
@@ -269,6 +297,11 @@ public:
         return solution_fitness_query;
     }
 
+    void set_stream_order_memory_allocation(bool flag)
+    {
+        stream_order_alloc = flag;
+    }
+
     // Sets the optimal size(s) of device memory for a kernel call
     // Maximum size is accumulated in device_memory_query_size
     // Returns rocblas_status_size_increased or rocblas_status_size_unchanged
@@ -349,7 +382,7 @@ private:
 
 #if ROCBLAS_REALLOC_ON_DEMAND
     // Helper for device memory allocator
-    bool device_allocator(size_t size);
+    bool ROCBLAS_EXPORT device_allocator(size_t size);
 #endif
 
     // Device ID is created at handle creation time and remains in effect for the life of the handle.
@@ -358,6 +391,7 @@ private:
     // Arch ID is created at handle creation time and remains in effect for the life of the handle.
     const int arch;
     int       archMajor;
+    int       archMajorMinor;
 
     // Opaque smart allocator class to perform device memory allocations
     // clang-format off
