@@ -182,52 +182,6 @@ catch(...)
     return exception_to_rocblas_status();
 }
 
-/*******************************************************************************
- * ! \brief query the preferable supported int8 input layout for gemm by device
- ******************************************************************************/
-extern "C" rocblas_status rocblas_query_int8_layout_flag(rocblas_handle      handle,
-                                                         rocblas_gemm_flags* flag)
-
-// This funnction is called by hipBLAS. The default is to use int8_t only
-// for gfx908. Other architectures use int8x4. This was the behavior before
-// ROCm 4.2. Support for int8_t for all architectures was provided by
-// by the following PRs for ROCm 4.2:
-// - Tensile PR 680
-// - rocBLAS-internal PR 1328
-// Setting rocblas_int8_type in the handle will result in this function
-// selecting int8_t or int8x4 regardless of architecture. It does this by
-// either setting or clearing the rocblas_gemm_flags_pack_int8x4 bit of flags.
-try
-{
-    if(!handle)
-        return rocblas_status_invalid_handle;
-
-    if(rocblas_int8_type_for_hipblas_default == handle->rocblas_int8_type)
-    {
-        *flag = handle->getArch() == 908 ? rocblas_gemm_flags_none : rocblas_gemm_flags_pack_int8x4;
-    }
-    else if(rocblas_int8_type_for_hipblas_int8 == handle->rocblas_int8_type)
-    {
-        *flag = rocblas_gemm_flags(*flag & (~rocblas_gemm_flags_pack_int8x4));
-    }
-    else if(rocblas_int8_type_for_hipblas_pack_int8x4 == handle->rocblas_int8_type)
-    {
-        *flag = rocblas_gemm_flags(*flag | rocblas_gemm_flags_pack_int8x4);
-    }
-    else
-    {
-        return rocblas_status_invalid_value;
-    }
-    // clear the rocblas_gemm_flags_pack_int8x4 bit
-    if(handle->layer_mode & rocblas_layer_mode_log_trace)
-        log_trace(handle, "rocblas_query_int8_layout_flag", *flag);
-    return rocblas_status_success;
-}
-catch(...)
-{
-    return exception_to_rocblas_status();
-}
-
 /*******************************************************************************
  * ! \brief create rocblas handle called before any rocblas library routines
  ******************************************************************************/
@@ -442,17 +396,17 @@ try
                 // host buffer -> device buffer
                 PRINT_IF_HIP_ERROR(hipMemcpy(t_d, t_h, contig_size, hipMemcpyHostToDevice));
                 // device buffer -> non-contiguous device vector
-                hipLaunchKernelGGL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
-                                   grid,
-                                   threads,
-                                   0,
-                                   0,
-                                   n_elem_max,
-                                   elem_size,
-                                   t_d,
-                                   1,
-                                   y_d_start,
-                                   incy);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
+                                      grid,
+                                      threads,
+                                      0,
+                                      0,
+                                      n_elem_max,
+                                      elem_size,
+                                      t_d,
+                                      1,
+                                      y_d_start,
+                                      incy);
             }
             else if(incx == 1 && incy != 1)
             {
@@ -464,17 +418,17 @@ try
                 // contiguous host vector -> device buffer
                 PRINT_IF_HIP_ERROR(hipMemcpy(t_d, x_h_start, contig_size, hipMemcpyHostToDevice));
                 // device buffer -> non-contiguous device vector
-                hipLaunchKernelGGL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
-                                   grid,
-                                   threads,
-                                   0,
-                                   0,
-                                   n_elem_max,
-                                   elem_size,
-                                   t_d,
-                                   1,
-                                   y_d_start,
-                                   incy);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
+                                      grid,
+                                      threads,
+                                      0,
+                                      0,
+                                      n_elem_max,
+                                      elem_size,
+                                      t_d,
+                                      1,
+                                      y_d_start,
+                                      incy);
             }
             else if(incx != 1 && incy == 1)
             {
@@ -563,17 +517,17 @@ try
                 if(!t_d)
                     return rocblas_status_memory_error;
                 // non-contiguous device vector -> device buffer
-                hipLaunchKernelGGL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
-                                   grid,
-                                   threads,
-                                   0,
-                                   0,
-                                   n_elem_max,
-                                   elem_size,
-                                   x_d_start,
-                                   incx,
-                                   t_d,
-                                   1);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
+                                      grid,
+                                      threads,
+                                      0,
+                                      0,
+                                      n_elem_max,
+                                      elem_size,
+                                      x_d_start,
+                                      incx,
+                                      t_d,
+                                      1);
                 // device buffer -> host buffer
                 PRINT_IF_HIP_ERROR(hipMemcpy(t_h, t_d, contig_size, hipMemcpyDeviceToHost));
                 // host buffer -> non-contiguous host vector
@@ -610,17 +564,17 @@ try
                 if(!t_d)
                     return rocblas_status_memory_error;
                 // non-contiguous device vector -> device buffer
-                hipLaunchKernelGGL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
-                                   grid,
-                                   threads,
-                                   0,
-                                   0,
-                                   n_elem_max,
-                                   elem_size,
-                                   x_d_start,
-                                   incx,
-                                   t_d,
-                                   1);
+                ROCBLAS_LAUNCH_KERNEL((rocblas_copy_void_ptr_vector_kernel<NB_X>),
+                                      grid,
+                                      threads,
+                                      0,
+                                      0,
+                                      n_elem_max,
+                                      elem_size,
+                                      x_d_start,
+                                      incx,
+                                      t_d,
+                                      1);
                 // device buffer -> contiguous host vector
                 PRINT_IF_HIP_ERROR(hipMemcpy(y_h_start, t_d, contig_size, hipMemcpyDeviceToHost));
             }
@@ -842,7 +796,7 @@ try
                 // host buffer -> device buffer
                 PRINT_IF_HIP_ERROR(hipMemcpy(t_d, t_h, contig_size, hipMemcpyHostToDevice));
                 // device buffer -> non-contiguous device matrix
-                hipLaunchKernelGGL(
+                ROCBLAS_LAUNCH_KERNEL(
                     (rocblas_copy_void_ptr_matrix_kernel<MATRIX_DIM_X, MATRIX_DIM_Y>),
                     grid,
                     threads,
@@ -866,7 +820,7 @@ try
                 // contiguous host matrix -> device buffer
                 PRINT_IF_HIP_ERROR(hipMemcpy(t_d, a_h_start, contig_size, hipMemcpyHostToDevice));
                 // device buffer -> non-contiguous device matrix
-                hipLaunchKernelGGL(
+                ROCBLAS_LAUNCH_KERNEL(
                     (rocblas_copy_void_ptr_matrix_kernel<MATRIX_DIM_X, MATRIX_DIM_Y>),
                     grid,
                     threads,
@@ -985,7 +939,7 @@ try
                 if(!t_d)
                     return rocblas_status_memory_error;
                 // non-contiguous device matrix -> device buffer
-                hipLaunchKernelGGL(
+                ROCBLAS_LAUNCH_KERNEL(
                     (rocblas_copy_void_ptr_matrix_kernel<MATRIX_DIM_X, MATRIX_DIM_Y>),
                     grid,
                     threads,
@@ -1033,7 +987,7 @@ try
                 if(!t_d)
                     return rocblas_status_memory_error;
                 // non-contiguous device matrix -> device buffer
-                hipLaunchKernelGGL(
+                ROCBLAS_LAUNCH_KERNEL(
                     (rocblas_copy_void_ptr_matrix_kernel<MATRIX_DIM_X, MATRIX_DIM_Y>),
                     grid,
                     threads,
@@ -1210,13 +1164,13 @@ extern "C" rocblas_status rocblas_set_start_stop_events(rocblas_handle handle,
 template <typename...>
 using void_t = void;
 
-// By default, use gcnArch converted to a string prepended by gfx
+// If gcnArchName not present, return empty string
 template <typename PROP, typename = void>
 struct ArchName
 {
     std::string operator()(const PROP& prop) const
     {
-        return "gfx" + std::to_string(prop.gcnArch);
+        return "";
     }
 };
 
@@ -1275,7 +1229,10 @@ bool rocblas_internal_tensile_supports_xdl_math_op(rocblas_math_mode mode)
     hipGetDevice(&deviceId);
     hipDeviceProp_t deviceProperties;
     hipGetDeviceProperties(&deviceProperties, deviceId);
-    return deviceProperties.gcnArch >= 940 && deviceProperties.gcnArch < 1000;
+    std::string deviceString(deviceProperties.gcnArchName);
+    return ((deviceString.find("gfx940") != std::string::npos)
+            || (deviceString.find("gfx941") != std::string::npos)
+            || (deviceString.find("gfx942") != std::string::npos));
 }
 
 // exported. Get architecture name
