@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2019-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2019-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -131,19 +131,12 @@ namespace
         using tensile_type = Tensile::BFloat16;
     };
 
-    // int8_t -> int8_t (supported for MI-kernel) / rocblas_int8x4 -> PackedInt8x4
     template <>
     struct rocblas_to_tensile_type<int8_t>
     {
         using tensile_type = int8_t;
     };
 
-    template <>
-    struct rocblas_to_tensile_type<rocblas_int8x4>
-    {
-        using tensile_type = Tensile::Int8x4;
-    };
-
     template <>
     struct rocblas_to_tensile_type<rocblas_f8>
     {
@@ -162,13 +155,9 @@ namespace
     template <typename>
     constexpr auto tensile_datatype = nullptr;
 
-    // int8_t -> int8_t (supported for MI-kernel) / rocblas_int8x4 -> PackedInt8x4
     template <>
     constexpr auto tensile_datatype<int8_t> = Tensile::DataType::Int8;
 
-    template <>
-    constexpr auto tensile_datatype<rocblas_int8x4> = Tensile::DataType::Int8x4;
-
     template <>
     constexpr auto tensile_datatype<int32_t> = Tensile::DataType::Int32;
 
@@ -212,6 +201,77 @@ namespace
         }
     }
 
+    Tensile::LazyLoadingInit getLazyLoadingArch(int deviceID)
+    {
+        hipDeviceProp_t deviceProperties;
+        hipGetDeviceProperties(&deviceProperties, deviceID);
+        // strip out xnack/ecc from name
+        std::string deviceFullString(deviceProperties.gcnArchName);
+        std::string deviceString = deviceFullString.substr(0, deviceFullString.find(":"));
+
+        if(deviceString.find("gfx803") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx803;
+        }
+        else if(deviceString.find("gfx900") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx900;
+        }
+        else if(deviceString.find("gfx906") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx906;
+        }
+        else if(deviceString.find("gfx908") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx908;
+        }
+        else if(deviceString.find("gfx90a") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx90a;
+        }
+        else if(deviceString.find("gfx940") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx940;
+        }
+        else if(deviceString.find("gfx941") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx941;
+        }
+        else if(deviceString.find("gfx942") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx942;
+        }
+        else if(deviceString.find("gfx1010") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1010;
+        }
+        else if(deviceString.find("gfx1011") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1011;
+        }
+        else if(deviceString.find("gfx1012") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1012;
+        }
+        else if(deviceString.find("gfx1030") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1030;
+        }
+        else if(deviceString.find("gfx1100") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1100;
+        }
+        else if(deviceString.find("gfx1101") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1101;
+        }
+        else if(deviceString.find("gfx1102") != std::string::npos)
+        {
+            return Tensile::LazyLoadingInit::gfx1102;
+        }
+        return Tensile::LazyLoadingInit::None;
+    }
+
     /*************************************************************************
      * Class for converting alpha and beta between rocBLAS and Tensile types *
      * By default, alpha and beta are the same type as Tc compute_type       *
@@ -373,10 +433,8 @@ namespace
         }
 
         // HPA is active iff sizeof(compute type) > sizeof(input type)
-        // but when Ti=int8x4 (32-byte),we still need to use HPA since the primitive data is int8
         tensileProblem.setHighPrecisionAccumulate(sizeof(Tc) > sizeof(TiA)
-                                                  || sizeof(Tc) > sizeof(TiB)
-                                                  || std::is_same<TiA, rocblas_int8x4>{});
+                                                  || sizeof(Tc) > sizeof(TiB));
 
         // Environment variable to force use of VALU for double precision gemm
         static bool force_valu_for_dgemm = std::getenv("ROCBLAS_INTERNAL_FORCE_VALU_FOR_DGEMM");
@@ -463,7 +521,6 @@ namespace
         using Tensile_Talpha_beta = typename AlphaBeta<TiA, To, Tc>::tensile_type;
 
         // Make sure rocBLAS and Tensile types are compatible
-        // (Even if Ti=rocblas_int8x4, Tensile_Ti=Int8x4, they are both 32-byte)
         static_assert(sizeof(Tensile_TiA) == sizeof(TiA) && sizeof(Tensile_TiB) == sizeof(TiB)
                           && sizeof(Tensile_To) == sizeof(To),
                       "Tensile and rocBLAS types are not the same size");
@@ -516,7 +573,7 @@ namespace
     {
         // The library object
         std::shared_ptr<Tensile::MasterSolutionLibrary<Tensile::ContractionProblem>> m_library;
-        std::shared_ptr<hipDeviceProp_t>                                             m_deviceProp;
+        std::unordered_map<std::string, std::shared_ptr<hipDeviceProp_t>> m_devicePropMap;
 
         // The adapter object. mutable is used to allow adapters to be modified
         // even when they are stored in a const vector which is immutable in size
@@ -568,9 +625,9 @@ namespace
             return m_library;
         }
 
-        auto& get_device_property() const
+        auto& get_device_property(const std::string& deviceName) const
         {
-            return m_deviceProp;
+            return m_devicePropMap.at(deviceName);
         }
 
         auto& get_adapters() const
@@ -599,9 +656,12 @@ namespace
             std::string path;
             std::string tensileLibraryPath;
             bool        tensile_lazy_load_enabled = false;
+            //Function local static-variables are used to gaurantee thread-safe initialization,
+            //avoids static initialization order fiasco
             static std::future<
                 std::shared_ptr<Tensile::SolutionLibrary<Tensile::ContractionProblem>>>
-                ftr_lib;
+                                                                ftr_lib;
+            static std::unordered_set<Tensile::LazyLoadingInit> tensileDeviceSet;
 
 #ifndef WIN32
             path.reserve(PATH_MAX);
@@ -619,55 +679,64 @@ namespace
             else if(xnack == "xnack-")
                 skip_xnack = "xnack+";
 
-            const char* env = getenv("ROCBLAS_TENSILE_LIBPATH");
-            if(env)
-            {
-                path = env;
-            }
-            else
-            {
-                path = ROCBLAS_LIB_PATH;
+            static std::string base_path;
+            static int         determine_tensile_base_path = [&] {
+                const char* env = getenv("ROCBLAS_TENSILE_LIBPATH");
+                if(env)
+                {
+                    base_path = env;
+                }
+                else
+                {
+                    base_path = ROCBLAS_LIB_PATH;
 
-                // Find the location of librocblas.dll/.so
-                // Fall back on hard-coded path if static library or not found
+                    // Find the location of librocblas.dll/.so
+                    // Fall back on hard-coded path if static library or not found
 
 #ifndef ROCBLAS_STATIC_LIB
 #ifdef WIN32
-                // wchar_t wpath[MAX_PATH + 1] = {0};
-                // if(GetModuleFileNameW(GetModuleHandle("rocblas.dll"), wpath, MAX_PATH + 1))
-                // {
-                //     std::wstring          wspath(wpath);
-                //     std::string           tmp(wspath.begin(), wspath.end());
+                    // wchar_t wpath[MAX_PATH + 1] = {0};
+                    // if(GetModuleFileNameW(GetModuleHandle("rocblas.dll"), wpath, MAX_PATH + 1))
+                    // {
+                    //     std::wstring          wspath(wpath);
+                    //     std::string           tmp(wspath.begin(), wspath.end());
 
-                std::vector<TCHAR> dll_path(MAX_PATH + 1);
-                if(GetModuleFileNameA(
-                       GetModuleHandleA("rocblas.dll"), dll_path.data(), MAX_PATH + 1))
-                {
-                    std::string           tmp(dll_path.begin(), dll_path.end());
-                    std::filesystem::path exepath = tmp;
-                    if(exepath.has_filename())
+                    std::vector<TCHAR> dll_path(MAX_PATH + 1);
+                    if(GetModuleFileNameA(
+                           GetModuleHandleA("rocblas.dll"), dll_path.data(), MAX_PATH + 1))
                     {
-                        path = exepath.remove_filename().string();
+                        std::string           tmp(dll_path.begin(), dll_path.end());
+                        std::filesystem::path exepath = tmp;
+                        if(exepath.has_filename())
+                        {
+                            base_path = exepath.remove_filename().string();
+                        }
                     }
-                }
 #else
-                dl_iterate_phdr(rocblas_dl_iterate_phdr_callback, NULL);
-                if(rocblas_so_path.size())
-                    path = std::string{dirname(&rocblas_so_path[0])};
+                    dl_iterate_phdr(rocblas_dl_iterate_phdr_callback, NULL);
+                    if(rocblas_so_path.size())
+                        base_path = std::string{dirname(&rocblas_so_path[0])};
 #endif
 #endif // ifndef ROCBLAS_STATIC_LIB
 
-                // Find the location of the libraries
-                if(TestPath(path + "/../../Tensile/library"))
-                    path += "/../../Tensile/library";
-                else if(TestPath(path + "/library"))
-                    path += "/library";
-                else
-                    path += "/rocblas/library";
+                    // Find the location of the libraries
+                    if(TestPath(base_path + "/../../Tensile/library"))
+                        base_path += "/../../Tensile/library";
+                    else if(TestPath(base_path + "/library"))
+                        base_path += "/library";
+                    else if(TestPath(base_path + "/../rocblas/library"))
+                        // For ASAN packaging, library file directory will be lib/asan
+                        // so need to prefix ../ to set search base_path to lib/rocblas/library
+                        base_path += "/../rocblas/library";
+                    else
+                        base_path += "/rocblas/library";
+                }
+                return 0;
+            }();
 
-                if(TestPath(path + "/" + processor))
-                    path += "/" + processor;
-            }
+            path = base_path;
+            if(TestPath(path + "/" + processor))
+                path += "/" + processor;
 
 #ifdef TENSILE_YAML
             tensileLibraryPath = path + "/TensileLibrary_lazy_" + processor + ".yaml";
@@ -719,6 +788,31 @@ namespace
             else
                 tensile_lazy_load_enabled = true;
 
+            //Supports multi architecture configuration in lazy library loading mode
+            static int initialize_once = [&] {
+                hipDeviceProp_t prop;
+                int             count;
+                HIP_CHECK_EXC(hipGetDeviceCount(&count));
+
+                for(int devId = 0; devId < count; devId++)
+                {
+                    auto deviceArch = getLazyLoadingArch(devId);
+                    if(tensileDeviceSet.find(deviceArch) == tensileDeviceSet.end())
+                    {
+                        //future work: populate the arch list for heterogeneous support
+                        tensileDeviceSet.insert(deviceArch);
+                        //populate device property map, used in finding solutions based on arch
+                        HIP_CHECK_EXC(hipGetDeviceProperties(&prop, devId));
+                        // strip out xnack/ecc from name
+                        std::string deviceFullString(prop.gcnArchName);
+                        std::string deviceString
+                            = deviceFullString.substr(0, deviceFullString.find(":"));
+                        m_devicePropMap[deviceString] = std::make_shared<hipDeviceProp_t>(prop);
+                    }
+                }
+                return 0;
+            }();
+
             if(!tensile_lazy_load_enabled || rocblas_initialize_called())
             {
 
@@ -807,14 +901,14 @@ namespace
                                      Tensile::LoadLibraryFilePreload<Tensile::ContractionProblem>,
                                      tensileLibraryPath,
                                      std::vector<Tensile::LazyLoadingInit>{});
-
                     return 0;
                 }();
-
-                adapter.initializeLazyLoading(processor, path);
             }
 
             {
+                // initialize adapter for lazy loading or experimental code objects
+                adapter.initializeLazyLoading(processor, path);
+
                 static int once = [&] {
                     auto lib = ftr_lib.get();
                     if(!lib)
@@ -835,18 +929,13 @@ namespace
                 rocblas_abort();
             }
 
-            hipDeviceProp_t prop;
-            HIP_CHECK_EXC(hipGetDeviceProperties(&prop, deviceId));
-
-            m_deviceProp = std::make_shared<hipDeviceProp_t>(prop);
-
             // Preload problem/solution mappings
             const char* overrideEnv = getenv("ROCBLAS_TENSILE_GEMM_OVERRIDE_PATH");
             if(overrideEnv)
             {
                 std::string                        overridePath = overrideEnv;
-                std::shared_ptr<Tensile::Hardware> hardware
-                    = Tensile::hip::GetDevice(*m_deviceProp);
+                std::shared_ptr<Tensile::Hardware> hardware     = Tensile::hip::GetDevice(
+                    *(get_device_property(rocblas_internal_get_arch_name())));
                 bool success = m_library->setOverridesFromFile(*hardware, overridePath);
 
                 if(!success)
@@ -901,7 +990,7 @@ namespace
         if(library)
             *library = host.get_library();
         if(deviceProp)
-            *deviceProp = host.get_device_property();
+            *deviceProp = host.get_device_property(rocblas_internal_get_arch_name());
 
         return *adapter;
     }
@@ -1022,7 +1111,7 @@ rocblas_status
             else if(handle->is_device_memory_size_query())
             {
                 status = handle->set_optimal_device_memory_size(
-                    ((solution->requiredWorkspaceSize(tensile_prob)
+                    ((solution->requiredWorkspaceSize(tensile_prob, *hardware)
                       + HPA_GSU_WORKSPACE_SIZE_GRANULARITY - 1)
                      / HPA_GSU_WORKSPACE_SIZE_GRANULARITY)
                     * HPA_GSU_WORKSPACE_SIZE_GRANULARITY);
@@ -1030,7 +1119,7 @@ rocblas_status
             else
             {
                 // check if the solution requires workspace for GSU and allocate it.
-                size_t WorkspaceSize = solution->requiredWorkspaceSize(tensile_prob);
+                size_t WorkspaceSize = solution->requiredWorkspaceSize(tensile_prob, *hardware);
                 auto   gsu_malloc    = prob.handle->gsu_malloc_by_size(WorkspaceSize);
 
                 if(solution->canSolve(tensile_prob, *hardware))
@@ -1303,11 +1392,6 @@ template rocblas_status
                           rocblas_gemm_algo algo,
                           int32_t           solution_index);
 
-template rocblas_status
-    runContractionProblem(const RocblasContractionProblem<rocblas_int8x4, int32_t, int32_t>&,
-                          rocblas_gemm_algo algo,
-                          int32_t           solution_index);
-
 // ********** get all solutions explicits ********
 // Non-HPA/GEMM types
 template rocblas_status getAllSolutions(const RocblasContractionProblem<rocblas_half>&,
@@ -1365,12 +1449,6 @@ template rocblas_status getAllSolutions(const RocblasContractionProblem<int8_t,
                                         rocblas_int*                        list_array,
                                         rocblas_int*                        list_size);
 
-template rocblas_status
-    getAllSolutions(const RocblasContractionProblem<rocblas_int8x4, int32_t, int32_t>&,
-                    rocblas_tensile_get_solution_option option,
-                    rocblas_int*                        list_array,
-                    rocblas_int*                        list_size);
-
 /***********************************************************************************
  * Whether Tensile has been initialized for at least one device (used for testing) *
  ***********************************************************************************/
